    * Encoding: UTF-8.

*===================================================================================*
    * TTULO DE LA SINTAXIS:*
    * Clculo: PARTICIPACIN DE EXPORTACIONES E IMPORTACIONES SEGN FUENTE DE INFORMACIN*
    * OPERACIN ESTADSTICA:*
    * Estadsticas de Transporte (ESTRA)*
    * Anuario de Estadsticas de Transporte 2022 - Transporte Areo*
    *DIRECCIN TCNICA RESPONSABLE:*
    * Direccin de Estadsticas Econmicas (DECON)*
    * ENTIDAD EJECUTORA:*
    * Instituto Nacional de Estadstica y Censos (INEC)*
*===================================================================================*
    * Fecha de elaboracin:            20 de julio de 2023*
    * Fecha ltima modificacin:     20 de julio de 2023*
*===================================================================================*
    * Elaborado por:*
    * Unidad de Gestin de Estadsticas Estructurales (GESE)*.
    * Gabriela Hidalgo.
    * Jenny Borja.
    *=============================================================================*
    * Revisado por:*
    * Roberto Chaves.
    * Jefe de Gestin de Estadsticas Estructurales (GESE)*.
    * Instituto Nacional de Estadstica y Censos
    * roberto_chaves@inec.gob.ec 
    *=============================================================================*
    * Aprobado por:*
    * Diana Barco
    * Directora de Estadsticas Econmicas (DECON)
    * Instituto Nacional de Estadstica y Censos
    * diana_barco@inec.gob.ec.
*=============================================================================*
*Instrucciones:.
*1.- Descarga la base de datos de Transporte Areo "2022_TRANSPORTE_AEREO_BDD" en formato SPSS de la pgina 
      web del INEC (http://www.ecuadorencifras.gob.ec//transporte/).
*2.- Guardar y abrir la base de datos "2022_TRANSPORTE_AEREO_BDD".

DATASET NAME AEREO.
DATASET COPY AEREO.
DATASET ACTIVATE AEREO.

****************************************************************************************************************************.
****PARTICIPACIN DE LAS IMPORTACIONES Y EXPORTACIONES VA AREA EN RELACIN**********.
**********************AL TOTAL DE IMPORTACIONES Y EXPORTACIONES DEL BCE***************************.
*****************************************************************************************************************************.

***Para calcular la proporcin solo se considera trfico internacional de carga***.

SELECT IF (Trfico=1 and Segmento=2).
EXECUTE.

***Agregando la base de datos por mes de entrada***.

DATASET DECLARE CARGA_1.
AGGREGATE
  /outfile='CARGA_1'
  /break= Movimiento
/Enero=SUM(ENE)
/Febrero=SUM(FEB)
/Marzo=SUM(MAR)
/Abril=SUM(ABR)
/Mayo=SUM(MAY)
/Junio=SUM(JUN)
/Julio=SUM(JUL)
/Agosto=SUM(AGO)
/Septiembre=SUM(SEP)
/Octubre=SUM(OCT)
/Noviembre=SUM(NOV)
/Diciembre=SUM(DIC).
DATASET ACTIVATE CARGA_1.


FLIP VARIABLES= Enero Febrero Marzo Abril Mayo Junio Julio Agosto Septiembre Octubre Noviembre 
    Diciembre 
  /NEWNAMES=Movimiento. 
 
DATASET NAME CARGA_2. 
DATASET ACTIVATE CARGA_2.

RENAME VARIABLES    CASE_LBL=Mes.
RENAME VARIABLES  K_1=Entrada.
RENAME VARIABLES  K_2=Salida.
 

recode Mes ("Enero"=1) ("Febrero"=2) ("Marzo"=3) ("Abril"=4) ("Mayo"=5) ("Junio"=6) ("Julio"=7) 
("Agosto"=8) ("Septiembre"=9) ("Octubre"=10) ("Noviembre"=11) ("Diciembre"=12) into MES_T.
execute.

variable labels MES_T "Mes".
formats MES_T (F2.0).
value labels MES_T
1 "ENERO"
2 "FEBRERO"
3 "MARZO"
4 "ABRIL"
5 "MAYO"
6 "JUNIO"
7 "JULIO"
8 "AGOSTO"
9 "SEPTIEMBRE"
10 "OCTUBRE"
11 "NOVIEMBRE"
12 "DICIEMBRE".
execute.

DELETE VARIABLES    Mes.


IF (MES_T=1) IMPORTACIONES_BCE=987727.
IF (MES_T=2) IMPORTACIONES_BCE=1122858.
IF (MES_T=3) IMPORTACIONES_BCE=1152745.
IF (MES_T=4) IMPORTACIONES_BCE=1002258.
IF (MES_T=5) IMPORTACIONES_BCE=863242.
IF (MES_T=6) IMPORTACIONES_BCE=982026.
IF (MES_T=7) IMPORTACIONES_BCE=796837.
IF (MES_T=8) IMPORTACIONES_BCE=915491.
IF (MES_T=9) IMPORTACIONES_BCE=1161061.
IF (MES_T=10) IMPORTACIONES_BCE=833028.
IF (MES_T=11) IMPORTACIONES_BCE=1000203.
IF (MES_T=12) IMPORTACIONES_BCE=905677.
EXECUTE.

VARIABLE LABELS IMPORTACIONES_BCE 'Total de importaciones - BCE'.
FORMATS IMPORTACIONES_BCE (F10.2).
EXECUTE.

IF (MES_T=1) EXPORTACIONES_BCE=1027427.
IF (MES_T=2) EXPORTACIONES_BCE=1019250.
IF (MES_T=3) EXPORTACIONES_BCE=1006096.
IF (MES_T=4) EXPORTACIONES_BCE=1057547.
IF (MES_T=5) EXPORTACIONES_BCE=1047913.
IF (MES_T=6) EXPORTACIONES_BCE=975386.
IF (MES_T=7) EXPORTACIONES_BCE=964589.
IF (MES_T=8) EXPORTACIONES_BCE=1083206.
IF (MES_T=9) EXPORTACIONES_BCE=1139930.
IF (MES_T=10) EXPORTACIONES_BCE=1048538.
IF (MES_T=11) EXPORTACIONES_BCE=997628.
IF (MES_T=12) EXPORTACIONES_BCE=1117468.
EXECUTE.
 
VARIABLE LABELS EXPORTACIONES_BCE 'Total de exportaciones - BCE'.
FORMATS EXPORTACIONES_BCE (F10.2).
EXECUTE.

*** CREANDO PARTICIPACIN PORCUENTUAL**

COMPUTE PIMPORT= (Entrada/IMPORTACIONES_BCE)*100.
FORMATS PIMPORT (F8.2).
VARIABLE LABELS PIMPORT 'Participacin de las importaciones transportadas por va area frente al total de importaciones nacionales no petroleras (%)'.
EXECUTE.

COMPUTE PEXPORT= (Salida/EXPORTACIONES_BCE)*100.
FORMATS PEXPORT (F8.2).
VARIABLE LABELS PEXPORT 'Participacin de las exportaciones transportadas por va area frente al total de exportaciones nacionales no petroleras (%)'.
EXECUTE.

***CUADRO N 45****.

****POR MES****.

CTABLES 
  /VLABELS VARIABLES=MES_T IMPORTACIONES_BCE EXPORTACIONES_BCE Entrada Salida PIMPORT PEXPORT 
    DISPLAY=LABEL 
  /TABLE MES_T BY IMPORTACIONES_BCE [S][SUM] + EXPORTACIONES_BCE [S][SUM] + Entrada [S][SUM] + 
    Salida [S][SUM] + PIMPORT [SUM] + PEXPORT [SUM] 
  /CATEGORIES VARIABLES=MES_T ORDER=A KEY=VALUE EMPTY=INCLUDE 
  /CRITERIA CILEVEL=95
  /TITLES 
    TITLE='CUADRO N 45'
            'TRANSPORTE AREO: PARTICIPACIN DE EXPORTACIONES E IMPORTACIONES SEGN FUENTE DE INFORMACIN, ao 2022'
            'POR MES'
            '(TONELADAS Y PORCENTAJES)'
    CAPTION='Elaboracin: Instituto Nacional de Estadstica y Censos - INEC'
                    'Fuente: Banco Central del Ecuador- Estadsticas de Comercio Exterior de Bienes' 
                    'INEC- Anuario de Estadsticas de Transporte 2022 - Direccin General de Aviacin Civil'.	


DATASET ACTIVATE CARGA_2.

COMPUTE TOTAL=1.
VALUE LABELS TOTAL 1 'NACIONAL'.
VARIABLE LABELS TOTAL 'TOTAL'.
FORMATS TOTAL (F1.0).
EXECUTE.


DATASET DECLARE NACIONAL.

AGGREGATE
  /outfile='NACIONAL'
  /break=TOTAL
  /EXPORTACIONES_BCE=SUM(EXPORTACIONES_BCE)
  /IMPORTACIONES_BCE=SUM(IMPORTACIONES_BCE)
  /Salida=SUM(Salida)
  /Entrada=SUM(Entrada).

DATASET ACTIVATE NACIONAL.

VARIABLE LABELS EXPORTACIONES_BCE 'Total de exportaciones - BCE'.
FORMATS EXPORTACIONES_BCE (F10.2).
EXECUTE.

VARIABLE LABELS IMPORTACIONES_BCE 'Total de importaciones - BCE'.
FORMATS IMPORTACIONES_BCE (F10.2).
EXECUTE.

VARIABLE LABELS Salida 'Total Carga Salida Va Area'.
VARIABLE LEVEL Salida (SCALE).
EXECUTE.

VARIABLE LABELS Entrada 'Total Carga Entrada Va Area'.
VARIABLE LEVEL Entrada (SCALE).
EXECUTE.

COMPUTE PEXPORT= (Salida/EXPORTACIONES_BCE)*100.
FORMATS PEXPORT (F8.2).
VARIABLE LABELS PEXPORT 'Participacin de las exportaciones transportadas por va area frente al total de exportaciones nacionales no petroleras (%)'.
EXECUTE.

COMPUTE PIMPORT= (Entrada/IMPORTACIONES_BCE)*100.
FORMATS PIMPORT (F8.2).
VARIABLE LABELS PIMPORT 'Participacin de las importaciones transportadas por va area frente al total de importaciones nacionales no petroleras (%)'.
EXECUTE.



CTABLES 
  /VLABELS VARIABLES=TOTAL EXPORTACIONES_BCE IMPORTACIONES_BCE Salida Entrada PEXPORT PIMPORT 
    DISPLAY=LABEL 
  /TABLE TOTAL [C] BY EXPORTACIONES_BCE [S][SUM] + IMPORTACIONES_BCE [S][SUM] + Salida [S][SUM] + 
    Entrada [S][SUM] + PEXPORT [S][SUM] + PIMPORT [S][SUM] 
  /CATEGORIES VARIABLES=TOTAL ORDER=A KEY=VALUE EMPTY=INCLUDE 
  /CRITERIA CILEVEL=95 
  /TITLES 
    TITLE='CUADRO N 45'
            'TRANSPORTE AREO: PARTICIPACIN DE EXPORTACIONES E IMPORTACIONES SEGN FUENTE DE INFORMACIN, ao 2022'
            'POR MES'
            '(TONELADAS Y PORCENTAJES)'
    CAPTION='Elaboracin: Instituto Nacional de Estadstica y Censos - INEC'
                    'Fuente: Banco Central del Ecuador- Estadsticas de Comercio Exterior de Bienes' 
                    'INEC- Anuario de Estadsticas de Transporte 2022 - Direccin General de Aviacin Civil'.	


DATASET ACTIVATE AEREO.
DATASET CLOSE CARGA_1.
DATASET ACTIVATE AEREO.
DATASET CLOSE CARGA_2.
DATASET ACTIVATE AEREO.
DATASET CLOSE NACIONAL.

