
#==============================================================================#
#####            ESTADÍSTICAS DE TRANSPORTE - ESTRA 2023                   #####
#==============================================================================#
#==============================================================================#
## GENERACIÓN DE TABULADOS - ESTADÍSTICAS DE TRANSPORTE, 2022               ####*
#==============================================================================#
#==============================================================================#
#####           INSTITUTO NACIONAL DE ESTADÍSTICA Y CENSOS (INEC)          #####*
#==============================================================================#
# FUENTE: Estadísticas de Transporte 2013 - 2022.
# RESPONSABLE: Gestión de Estadísticas Estructurales (GESE).
# Fecha de elaboración: Agosto 2023.
# Fecha de Última actualización: 09/08/2023.
# ==============================================================================*
# ==============================================================================*
# Elaborado por:
# Unidad de Gestión de Estadísticas Estructurales (GESE).
# Gabriela Hidalgo
# Jenny Borja
# ==============================================================================*
# Revisado por:
# # Roberto Chaves
# Jefe de Gestión de Estadísticas Estructurales (GESE)
# Instituto Nacional de Estadística y Censos
# ==============================================================================*
# Aprobado por: 
# Diana Barco
# Directora de Estadísticas Económicas (DECON)
# Instituto Nacional de Estadística y Censos 
# Diana_Barco@inec.gob.ec
# ==============================================================================*

# ==============================================================================*

######                           INSTRUCCIONES                             #####*

# 1.- Descargar las base de datos de los componentes de las Estadísticas de 
# Transporte 2022 en formato SPSS de la página web del INEC:
#
# (https://www.ecuadorencifras.gob.ec/transporte/).

# 2.- En el disco C: de su computadora, crear una carpeta llamada "Tabulados ESTRA 2022". 
# En esta carpeta  guardar las bases de datos (históricas) con esta sintaxis y 
# se exportará todos los resultados en Excel (Tabulados).
# ==============================================================================*

# **************************************************************************** #
######                                NOTA                                 ##### *
#
# En este SCRIPT, se encuentra toda la programación necesaria para la generación
# de los diferentes tabulados. Estos se ha realizado en R-STUDIO. 

# **************************************************************************** #

# ============================================================================ #
######                            PASOS PREVIOS                           ######
# ============================================================================ #

##### Limpiar el espacio de trabajo #####

rm(list=ls())
cat("\014")

##### Instalacion de paquetes #####
"En caso de saltar error en la carga de librerias, instalar los paquetes quitando 
los '#' de los siguientes codigos:" 

# install.packages("tidyverse")
# install.packages("openxlsx")
# install.packages("dplyr")
# install.packages("haven")
# install.packages("stringr")
# install.packages("janitor")
# install.packages("Hmisc")

##### Carga de librerias #####

library(tidyverse)
library(openxlsx)
library(dplyr)
library(haven)
library(stringr)
library(janitor)
library(Hmisc)

#==============================================================================#
# Importar base de datos  y ruta de trabajo
#==============================================================================#

setwd("C:/Tabulados ESTRA 2022") # Directorio de trabajo 
dir()  # Ver los documentos

#==============================================================================#
#  Carga de bases de datos
#==============================================================================#

vehiculos <- read_sav("2022_VEHÍCULOS_MATRICULADOS_BDD.sav")
siniestros <- read_sav("2022_SINIESTROS_TRÁNSITO_BDD.sav")
aereo <- read_sav("2022_TRANSPORTE_AEREO_BDD.sav")
maritimo <- read_sav("2022_TRANSPORTE_MARÍTIMO_BDD.sav")

#==============================================================================#
#####                        CREACION DE FUNCIONES                         ##### 
#==============================================================================#

"Funcion para mover cualquier fila al inicio"
final <- function(df, row) {
  stopifnot(nrow(df) >= row) 
  rbind(df[row, ], df[-row, ])
}

"Funcion para realizar los tabulados con total de colunma al inicio"
estra <- function(df, vertical, horizontal) { 
  tab <- df %>% 
    select(all_of(c(vertical, horizontal))) %>%  
    mutate_if(is.double, as_factor) %>% 
    group_by(!!!syms(vertical),!!!syms(horizontal))%>%
    tally() %>%
    spread(horizontal, `n`)%>% 
    mutate(Total = rowSums(across(where(is.numeric)), na.rm=TRUE)) %>% 
    select(vertical,Total, everything()) %>% 
    ungroup() %>% 
    bind_rows(summarise(., across(where(is.numeric), sum, na.rm=TRUE))) %>% 
    mutate_if(is.numeric, ~replace_na(., 0)) %>%
    rename_at(-c(1:2), ~ str_to_title(.)) %>% 
    mutate_at(c(1:1), ~ str_to_title(.)) 
  return(tab)
}

"Funcion para tabulados con tres variables y total al inicio"
estra.2 <- function(df, vertical, horizontal, relleno) { 
  tab <- df %>% 
    select(!!!syms(vertical),!!!syms(horizontal),!!!syms(relleno)) %>%  
    mutate_at(c(1:1), as_factor) %>%   
    group_by(!!!syms(vertical))%>%
    mutate(Capacidad = (sum(!!!syms(relleno), na.rm = T)))%>% 
    select(vertical, Capacidad) %>% 
    ungroup() %>% 
    distinct() %>%
    bind_rows(summarise(., across(where(is.numeric), sum, na.rm=TRUE))) %>% 
    rename_at(-c(1:3), ~ str_to_title(.)) %>% 
    mutate_at(c(1:1), ~ str_to_title(.)) 
  tab2 <- estra(df, vertical = `vertical`, horizontal = `horizontal`)  
  tab <- right_join(tab,tab2, by = `vertical`)
  return(tab)
}

"Funcion para tabulados con dos variables y total al final"
estra.3 <- function(df, vertical, horizontal, relleno) { 
  tab <- df %>% 
    select(all_of(c(vertical, horizontal, relleno))) %>%  
    group_by(!!!syms(vertical),!!!syms(horizontal))%>%
    summarise(Total = (sum(!!!syms(relleno),na.rm = T))) %>%
    spread(horizontal, Total) %>% 
    mutate(Total = rowSums(across(where(is.numeric)), na.rm=TRUE)) %>% 
    ungroup() %>% 
    bind_rows(summarise(., across(where(is.numeric), sum, na.rm=TRUE))) %>% 
    rowwise()
  return(tab)
}

"Funcion para realizar tabulados con porcentajes"
estra.participacion <- function(df, vertical, horizontal, relleno) { 
  tab <- df %>% 
    group_by(!!!syms(horizontal)) %>%
    rowwise() %>% 
    mutate(total = sum(!!!syms(relleno), na.rm = T)) %>% 
    select(!!!syms(vertical),!!!syms(horizontal),total) %>% 
    group_by(!!!syms(horizontal)) %>%
    mutate(porcentaje  = (`total` / sum(`total`)*100)) %>% 
    group_by(!!!syms(horizontal)) %>%
    group_modify(~ add_row(.x,.before=0)) %>% 
    mutate(total = ifelse((is.na(total)),sum(total,na.rm = T),total)) %>% 
    mutate(porcentaje = ifelse((is.na(porcentaje)), (sum(total,na.rm = T)/sum(total,na.rm = T))*100,porcentaje)) %>% 
    mutate(Origen = ifelse((is.na(Origen)),str_c("Total Región",Destino, sep = " "),Origen)) %>% 
    mutate(Destino = ifelse((is.na(Destino)),str_c("Total Región",Origen, sep = " "),Destino))
  return(tab)
}

"Funcion para realizaer tabulados de transporte maritimo"
estra.maritimo <- function(df, vertical, horizontal, relleno) {
  tab <- df %>%
    select(!!!syms(vertical),!!!syms(horizontal),!!!syms(relleno)) %>%
    group_by(!!!syms(vertical),!!!syms(horizontal))%>%
    mutate_at(c(1:2), as_factor) %>%  
    summarise(Total = (sum(!!!syms(relleno),na.rm = T))) %>%
    spread(horizontal, Total) %>%
    ungroup() %>% 
    bind_rows((summarise(., across(where(is.numeric), sum, na.rm=TRUE)))) %>%
    rowwise() %>%
    mutate(Total = (rowSums(across(where(is.numeric)), na.rm=TRUE))) %>%
    select(vertical,Total, everything()) %>%
    mutate(Total = case_when((Total == 0)~(NA),
                             (T)~(Total))) %>%
    drop_na(Total) %>%
    mutate_if(is.numeric, round_half_up) %>% 
    mutate_if(is.numeric, ~replace_na(., 0)) %>%
    mutate_at(c(1:1), ~ str_to_title(.)) 
  tab<- final(tab,nrow(tab))
  return(tab)
}

"Funcion para realizar tabulados con mas de dos variables"
estra.frecuencias <- function(df, vertical, horizontal1, horizontal2,
                              horizontal3, horizontal4, horizontal5) {
  tab <- df %>%
    select(all_of(c(vertical, horizontal1, horizontal2,
                    horizontal3,horizontal4,horizontal5))) %>%  
    group_by(!!!syms(vertical))%>%
    summarise(a = (sum(!!!syms(horizontal1), na.rm = T)),
              b = (sum(!!!syms(horizontal2), na.rm = T)),
              c = (sum(!!!syms(horizontal3), na.rm = T)),
              d = (sum(!!!syms(horizontal4), na.rm = T)),
              e = (sum(!!!syms(horizontal5), na.rm = T)))%>%
    ungroup() %>%
    bind_rows(summarise(., across(where(is.numeric), sum, na.rm=TRUE)))%>%
    mutate_if(is.numeric, round_half_up) %>%
    mutate_at(c(1:1), ~ str_to_title(.)) 
  tab <- final(tab,nrow(tab))
  tab <- tab %>%
    arrange(desc(a))
  return(tab)
}

"Funcion para realizar tabulados de transporte aereo"
aereo.2 <- function(df, vertical, horizontal, relleno) {
  tab <- df %>%
    select(!!!syms(vertical),!!!syms(horizontal),!!!syms(relleno)) %>%
    group_by(!!!syms(vertical),!!!syms(horizontal))%>%
    mutate_at(c(1:2), as_factor) %>%  
    summarise(a = (sum(!!!syms(relleno),na.rm = T))) %>%
    spread(horizontal, a) %>%
    ungroup() %>%
    bind_rows((summarise(., across(where(is.numeric), sum, na.rm=TRUE)))) %>%
    rowwise() %>%
    mutate(TOTAL = (rowSums(across(where(is.numeric)), na.rm=TRUE))) %>%
    select(vertical,TOTAL, everything()) %>%
    mutate(TOTAL = case_when((TOTAL == 0)~(NA),
                             (T)~(TOTAL))) %>%
    drop_na(TOTAL)
  tab<- final(tab,nrow(tab))
  return(tab)
}

# ============================================================================ #
######         CREACION DE TABULADOS PARA VEHICULOS MATRICULADOS          ######
# ============================================================================ #
"En esta sección se generarán los tabulados concernientes a vehículos motorizados 
matrículados (V.M.m)"

##### Tabulado 01: V.M.m segun uso por provincias #####
vm1.1 <- estra(vehiculos,vertical = "PROVINCIA", horizontal = "SERVICIO") %>% 
         arrange(PROVINCIA) %>% 
         slice(1,2,4,3, 5:25)
vm1 <- final(vm1.1,nrow(vm1.1))
rm(vm1.1)

##### Tabulado 02: V.M.m segun uso por clase #####
vm2.1 <- estra(vehiculos,vertical = "CLASE", horizontal = "SERVICIO")
vm2 <- final(vm2.1,nrow(vm2.1))
rm(vm2.1)

##### Tabulado 03: V.M.m segun servicio por modelo #####
vm3.1 <- estra(vehiculos,vertical = "MODELO", horizontal = "SERVICIO")
vm3 <- final(vm3.1,nrow(vm3.1))
rm(vm3.1)

##### Tabulado 04: V.M.m segun servicio por canton ##### 
vm4 <- estra(vehiculos,vertical = c("PROVINCIA","CANTÓN"), horizontal = "SERVICIO") %>% 
  mutate(CANTÓN=as_factor(CANTÓN)) %>% 
  select(-Total) %>% 
  slice(-n()) %>% 
  rename_at(-c(1:2), ~ str_to_title(.)) %>% 
  mutate_at(c(1:2), ~ str_to_title(.)) %>% 
  arrange(PROVINCIA) %>% 
  slice(1:22, 29:35 , 23:28 , 36:221)

##### Tabulado 05: V.M.m segun clase por provincia #####
vm5.1 <- estra(vehiculos,vertical = "PROVINCIA", horizontal = "CLASE") %>% 
         arrange(PROVINCIA) %>% 
         slice(1,2,4,3, 5:25)
vm5 <- final(vm5.1,nrow(vm5.1))
rm(vm5.1)

##### Tabulado 06: V.M.m segun modelo por clase #####
vm6.1 <- estra(vehiculos,vertical = "CLASE", horizontal = "MODELO")
vm6 <- final(vm6.1,nrow(vm6.1))
rm(vm6.1)

##### Tabulado 07: V.M.m segun modelo por marca #####
vm7.1 <- estra(vehiculos,vertical = "MARCA", horizontal = "MODELO") %>% 
         arrange(desc(Total)) %>% 
         mutate(MARCA=ifelse(rank(-Total, ties.method = "first") <= 31, MARCA, 
                             "Otras Marcas")) %>% 
         group_by(MARCA) %>% 
         summarise(across(everything(), sum)) %>% 
         ungroup() %>% 
         arrange(MARCA == "Otras Marcas", desc(Total))
vm7 <- final(vm7.1,nrow(vm7.1))
rm(vm7.1)

##### Tabulado 08: V.M.m segun modelo por provincia #####
vm8.1 <- estra(vehiculos,vertical = "PROVINCIA", horizontal = "MODELO") %>% 
         arrange(PROVINCIA) %>% 
         slice(1,2,4,3, 5:25)
vm8 <- final(vm8.1,nrow(vm8.1))
rm(vm8.1)

##### Tabulado 09: V.M.m segun clase por marca #####
vm9.1 <- estra(vehiculos,vertical = "MARCA", horizontal = "CLASE") %>% 
         arrange(desc(Total)) %>% 
         mutate(MARCA=ifelse(rank(-Total, ties.method = "first") <= 31, MARCA, 
                             "Otras Marcas")) %>% 
         group_by(MARCA) %>% 
         summarise(across(everything(), sum)) %>% 
         ungroup() %>% 
         arrange(MARCA == "Otras Marcas", desc(Total))
vm9 <- final(vm9.1,nrow(vm9.1))
rm(vm9.1)

##### Tabulado 10: V.M.m segun capacidad de pasajeros por clase #####
vehiculos2 <- vehiculos  %>% 
  filter(CLASE == 1  |  CLASE == 6  |  CLASE == 7  |  CLASE == 2  |  
         CLASE == 5  |  CLASE == 11)
vm10 <- estra.2(vehiculos2, vertical="CLASE", horizontal="ESTRAPASAJERO", 
                relleno="PASAJEROS") %>% 
        rename(`Capacidad de pasajeros` = Capacidad) %>% 
        arrange(desc(`Capacidad de pasajeros`))

##### Tabulado 11: V.M.m segun capacidad de carga por clase #####
vehiculos2 <- vehiculos %>% 
  filter(CLASE == 3  |  CLASE == 4  |  CLASE == 8  |  CLASE == 9  | CLASE == 10)
vm11 <- estra.2(vehiculos2, vertical="CLASE", horizontal="ESTRATONE", 
                relleno="TONELAJE")  %>% 
        rename(`Capacidad de carga` = Capacidad) %>% 
        arrange(desc(`Capacidad de carga`)) 

##### Tabulado 12: V.M.m segun capacidad de pasajeros por provincia #####
vehiculos2 <- vehiculos  %>% 
  filter(CLASE == 1  |  CLASE == 6  |  CLASE == 7  |  CLASE == 2  |  
         CLASE == 5  |  CLASE == 11)
vm12.1 <- estra.2(vehiculos2, vertical="PROVINCIA", horizontal="ESTRAPASAJERO", 
                  relleno="PASAJEROS") %>% 
        rename(`Capacidad de pasajeros` = Capacidad) %>% 
        arrange(PROVINCIA) %>% 
        slice(1,2,4,3, 5:25)
vm12 <- final(vm12.1,nrow(vm12.1))
rm(vm12.1)

##### Tabulado 13: V.M.m segun capacidad de carga por provincia #####
vehiculos2 <- vehiculos %>% 
  filter(CLASE == 3  |  CLASE == 4  |  CLASE == 8  |  CLASE == 9  | CLASE == 10)
vm13.1 <- estra.2(vehiculos2, vertical="PROVINCIA", horizontal="ESTRATONE", 
                  relleno="TONELAJE")  %>% 
        rename(`Capacidad de carga` = Capacidad) %>% 
        arrange(PROVINCIA) %>% 
        slice(1,2,4,3, 5:25)
vm13 <- final(vm13.1,nrow(vm13.1))
rm(vm13.1)

##### Tabulado 14: V.M.m segun uso de vehiculo por provincia y tipo de combustible #####
vm14.1 <- estra(vehiculos, vertical = c("PROVINCIA","COMBUSTIBLE"), horizontal = "SERVICIO") %>% 
  slice(-n()) %>% 
  arrange(PROVINCIA) %>% 
  slice(1:12, 19:24 , 13:18 , 25:137)

vm14.2 <- estra(vehiculos, vertical = c("COMBUSTIBLE"), horizontal = "SERVICIO") %>% 
  mutate(PROVINCIA = "Total") %>% 
  select(PROVINCIA, everything()) %>% 
  slice(-n()) 

vm14 <- bind_rows(vm14.2, vm14.1) 
rm(vm14.1, vm14.2)

##### Tabulado 15: V.M.m segun uso de vehiculo por clase y tipo de combistible #####
vm15.1 <- estra(vehiculos, vertical = c("CLASE","COMBUSTIBLE"), horizontal = "SERVICIO") %>% 
  slice(-n())

vm15.2 <- estra(vehiculos, vertical = c("COMBUSTIBLE"), horizontal = "SERVICIO") %>% 
  mutate(CLASE = "Total") %>% 
  select(CLASE, everything()) %>% 
  slice(-n())

vm15 <- bind_rows(vm15.2, vm15.1)  
rm(vm15.1, vm15.2)

##### Tabulado 16: V.M.m por cada 1000 habitantes, por provincia #####
"Nota: Se crea la variable poblacion año 2022"

Provincia <- c("Azuay",
               "Bolívar",
               "Cañar",
               "Carchi",
               "Chimborazo",
               "Cotopaxi",
               "El Oro",
               "Esmeraldas",
               "Galápagos",
               "Guayas",
               "Imbabura",
               "Loja",
               "Los Ríos",
               "Manabí",
               "Morona Santiago",
               "Napo","Orellana",
               "Pastaza",
               "Pichincha",
               "Santa Elena",
               "Santo Domingo De Los Tsáchilas",
               "Sucumbíos",
               "Tungurahua",
               "Zamora Chinchipe")

Población <- c(846045,
               215936,
               287095,
               173115,
               517999,
               482765,
               762792,
               635274,
               27791,
               4672735,
               489990,
               520535,
               1019247,
               1677443,
               236426,
               143976,
               186435,
               125240,
               3051300,
               409139,
               562444,
               223438,
               590595,
               121151)

vm16.1 <- data.frame(Provincia, Población) %>% 
  mutate(Provincia = chartr("áéíóú", "aeiou", Provincia))

vm16.2 <- vehiculos %>% 
  select(PROVINCIA) %>% 
  mutate(PROVINCIA = as_factor(PROVINCIA)) %>% 
  group_by(PROVINCIA) %>%
  tally() %>% 
  mutate_at(c(1:2), ~ str_to_title(.)) %>% 
  rename("Provincia" = PROVINCIA) %>% 
  mutate(n = as.numeric(n))

"Nota: Se calcula un indicador
1. Número de vehículos matriculados por cada 1000 habitantes = 
  (Número de vehículos matriculados/Población año 2022) * 1.000"

vm16 <- merge(vm16.2, vm16.1, by = "Provincia", all = T) %>% 
  mutate(indicador=(n/Población)*1000) %>% 
  bind_rows(summarise(., across(where(is.numeric), sum, na.rm=TRUE)))

vm16 <- final(vm16,nrow(vm16))
rm(vm16.1, vm16.2)

##### Tabulado 17: V.M.m, serie histórica 2013-2022 por provincias #####
"Nota: La serie historica se encuentra en los tabulados"

# ============================================================================ #
######         CREACION DE TABULADOS PARA SINIESTROS DE TRANSITO          ######
# ============================================================================ #
"En esta sección se generarán los tabulados concernientes a siniestros de transito (S.T.)"

##### Tabulado 18: S.T. segun mes, por provincia #####
st18.1 <- siniestros %>% 
  select(PROVINCIA, MES) %>%  
  mutate_if(is.double, as_factor) %>% 
  group_by(PROVINCIA, MES)%>%
  tally() %>%
  spread(MES, `n`) %>% 
  mutate(Total = rowSums(across(where(is.numeric)), na.rm=TRUE)) %>% 
  select(PROVINCIA, Total, everything()) %>% 
  ungroup() %>% 
  complete(PROVINCIA,  fill = list(total = 0)) %>% 
  bind_rows(summarise(., across(where(is.numeric), sum, na.rm=TRUE))) %>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  rename_at(-c(1:2), ~ str_to_title(.)) %>% 
  mutate_at(c(1:1), ~ str_to_title(.)) %>% 
  arrange(PROVINCIA) %>% 
  slice(1,2,4,3, 5:25)
st18 <- final(st18.1,nrow(st18.1))
rm(st18.1)

##### Tabulado 19: S.T. segun clase, por provincia #####
st19.1 <- siniestros %>% 
  select(PROVINCIA, CLASE) %>%  
  mutate_if(is.double, as_factor) %>% 
  group_by(PROVINCIA, CLASE)%>%
  tally() %>%
  spread(CLASE, `n`) %>% 
  mutate(Total = rowSums(across(where(is.numeric)), na.rm=TRUE)) %>% 
  select(PROVINCIA, Total, everything()) %>% 
  ungroup() %>% 
  complete(PROVINCIA,  fill = list(total = 0)) %>% 
  bind_rows(summarise(., across(where(is.numeric), sum, na.rm=TRUE))) %>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  rename_at(-c(1:2), ~ str_to_title(.)) %>% 
  mutate_at(c(1:1), ~ str_to_title(.)) %>% 
  arrange(PROVINCIA) %>% 
  slice(1,2,4,3, 5:25)
st19 <- final(st19.1,nrow(st19.1))
rm(st19.1)

##### Tabulado 20: S.T. segun meses, por clase #####
st20.1 <- estra(siniestros,vertical = "CLASE", horizontal = "MES")
st20 <- final(st20.1,nrow(st20.1))
rm(st20.1)

##### Tabulado 21: S.T. segun causa, por provincia #####
st21.1 <- siniestros %>% 
    select(PROVINCIA, CAUSA) %>%  
    mutate_if(is.double, as_factor) %>% 
    group_by(PROVINCIA, CAUSA)%>%
    tally() %>%
    spread(CAUSA, `n`) %>% 
    mutate(Total = rowSums(across(where(is.numeric)), na.rm=TRUE)) %>% 
    select(PROVINCIA, Total, everything()) %>% 
    ungroup() %>% 
    complete(PROVINCIA,  fill = list(total = 0)) %>% 
    bind_rows(summarise(., across(where(is.numeric), sum, na.rm=TRUE))) %>% 
    mutate_if(is.numeric, ~replace_na(., 0)) %>%
    rename_at(-c(1:2), ~ str_to_title(.)) %>% 
    mutate_at(c(1:1), ~ str_to_title(.)) %>% 
  arrange(PROVINCIA) %>% 
  slice(1,2,4,3, 5:25)
st21 <- final(st21.1,nrow(st21.1))
rm(st21.1)

##### Tabulado 22: S.T. segun meses, por causa #####
st22.1 <- estra(siniestros,vertical = "CAUSA", horizontal = "MES")
st22 <- final(st22.1,nrow(st22.1))
rm(st22.1)

##### Tabulado 23: Victimas en S.T.,  por provincia #####
st23.1 <- siniestros %>% 
  select(PROVINCIA, TOTAL_VICTIMAS,NUM_FALLECIDO,NUM_LESIONADO) %>% 
  mutate(PROVINCIA = as_factor(PROVINCIA)) %>% 
  group_by(PROVINCIA) %>%
  summarise("TOTAL DE VÍCTIMAS" = sum(TOTAL_VICTIMAS, na.rm = TRUE),
            FALLECIDOS = sum(NUM_FALLECIDO, na.rm = TRUE),
            LESIONADOS = sum(NUM_LESIONADO, na.rm = TRUE)) %>% 
  ungroup() %>% 
  complete(PROVINCIA,  fill = list(total = 0)) %>% 
  bind_rows(summarise(., across(where(is.numeric), sum, na.rm=TRUE))) %>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  rename_at(-c(1:2), ~ str_to_title(.)) %>% 
  mutate_at(c(1:1), ~ str_to_title(.)) %>% 
  arrange(PROVINCIA) %>% 
  slice(1,2,4,3, 5:25)

st23 <- final(st23.1,nrow(st23.1))
rm(st23.1)

##### Tabulado 24: Indicadores S.T.,  por provincia #####
st24.1 <- data.frame(Provincia, Población) %>% 
  mutate(Provincia = chartr("áéíóú", "aeiou", Provincia))

st24.2 <- siniestros %>% 
  select(PROVINCIA, NUM_FALLECIDO, NUM_LESIONADO) %>% 
  mutate(PROVINCIA = as_factor(PROVINCIA)) %>% 
  group_by(PROVINCIA) %>%
  summarise(SINIESTROST= n(),
            FALLECIDOS = sum(NUM_FALLECIDO, na.rm = T),
            LESIONADOS = sum(NUM_LESIONADO, na.rm = T)) %>% 
  ungroup() %>% 
  mutate_at(c(1:2), ~ str_to_title(.)) %>% 
  rename("Provincia" = PROVINCIA) %>% 
  mutate(Provincia = chartr("áéíóú", "aeiou", Provincia)) %>% 
  mutate(SINIESTROST=as.numeric(SINIESTROST))

st24.3 <- vehiculos %>% 
  select(PROVINCIA) %>% 
  mutate(PROVINCIA = as_factor(PROVINCIA)) %>% 
  group_by(PROVINCIA) %>%
  tally() %>% 
  mutate_at(c(1:2), ~ str_to_title(.)) %>% 
  rename("Provincia" = PROVINCIA) %>% 
  mutate(n = as.numeric(n))

"Nota: Se calculan cuatro indicadores
1. Tasa de mortalidad por accidentes de tránsito por cada 100.000 habitantes= 
   (Número de fallecidos / Población año 2022) * 100.000
   
2. Lesionados por cada 100 Siniestros de Tránsito=
   (Número de lesionados / Siniestros de tránsito) * 100
   
3. Fallecidos  por cada 100 Siniestros de tránsito 
   (Número de fallecidos / Siniestros de tránsito) * 100
  
4. Número de Siniestros de Tránsito por cada 1.000 vehículos matriculados=
   (Siniestros de tránsito / Número de vehículos matriculados) * 1.000"

st24 <- merge(st24.2, st24.3, by = "Provincia", all = T) %>% 
  left_join(st24.1, by = "Provincia") %>% 
  mutate(mortalidad=(FALLECIDOS/Población)*100000) %>% 
  mutate(lesionados=(LESIONADOS/SINIESTROST)*100) %>% 
  mutate(fallecidos=(FALLECIDOS/SINIESTROST)*100) %>% 
  mutate(vehiculos=(SINIESTROST/n)*1000) %>% 
  bind_rows(summarise(., across(where(is.numeric), sum, na.rm=TRUE)))

st24 <- final(st24,nrow(st24))
rm(st24.1, st24.2, st24.3)

##### Tabulado 25: S.T., fallecidos y heridos, serie historica 2013-2022 por provincia #####
"Nota: La serie historica se encuentra en los tabulados"


# ============================================================================ #
######            CREACION DE TABULADOS PARA TRANSPORTE AEREO             ######
# ============================================================================ #
"En esta sección se generarán los tabulados concernientes a 
transporte aereo internacional (T.A.I.) y trafico aereo domestico (T.A.D)"

##### Generalidades tabulados transporte aereo #####
"Se modifica la data para que se elimine la notación cientifica"
options(scipen=999)

"Se genera una nueva variable en la que se especirfica el origen y destino según zona"
aereo <- aereo %>% 
  mutate(Región = case_when((Origen == 'Amsterdam')~('Europa'),
                            (Origen == 'Asunción')~('Cono Sur'),
                            (Origen == 'Atlanta')~('Norte América'),
                            (Origen == 'Barranquilla')~('Comunidad Andina'),
                            (Origen == 'Belo Horizonte (Brasil)')~('Cono Sur'),
                            (Origen == 'Bogotá')~('Comunidad Andina'),
                            (Origen == 'Buenos Aires')~('Cono Sur'),
                            (Origen == 'Cali')~('Comunidad Andina'),
                            (Origen == 'Chicago')~('Norte América'),
                            (Origen == 'Curitiba')~('Cono Sur'),
                            (Origen == 'Doha (Qatar)')~('Asia'),
                            (Origen == 'El Salvador')~('Centro América'),
                            (Origen == 'Florianopolis (Brasil)')~('Cono Sur'),
                            (Origen == 'Fort Lauderdale')~('Norte América'),
                            (Origen == 'Guatemala (La Aurora)')~('Centro América'),
                            (Origen == 'Houston')~('Norte América'),
                            (Origen == 'Lima')~('Comunidad Andina'),
                            (Origen == 'Louisville (Estados Unidos)')~('Norte América'),
                            (Origen == 'Luxemburgo')~('Europa'),
                            (Origen == 'Madrid')~('Europa'),
                            (Origen == 'Manaos')~('Cono Sur'),
                            (Origen == 'México')~('Norte América'),
                            (Origen == 'Miami')~('Norte América'),
                            (Origen == 'New York')~('Norte América'),
                            (Origen == 'Panamá')~('Centro América'),
                            (Origen == 'Río Negro')~('Comunidad Andina'),
                            (Origen == 'San José')~('Centro América'),
                            (Origen == 'Santiago')~('Cono Sur'),
                            (Origen == 'Santo Domingo (Rep.  Dominicana)')~('Centro América'),
                            (Origen == 'Sao Paulo')~('Cono Sur'),
                            (Origen == 'Toronto')~('Norte América'),
                            (Origen == 'Viracopos')~('Cono Sur'),
                            (Destino == 'Aguadilla')~('Centro América'),
                            (Destino == 'Amsterdam')~('Europa'),
                            (Destino == 'Aruba')~('Centro América'),
                            (Destino == 'Atlanta')~('Norte América'),
                            (Destino == 'Barranquilla')~('Comunidad Andina'),
                            (Destino == 'Buenos Aires')~('Cono Sur'),
                            (Destino == 'Curacao')~('Centro América'),
                            (Destino == 'Doha (Qatar)')~('Asia'),
                            (Destino == 'Dubai')~('Asia'),
                            (Destino == 'El Salvador')~('Centro América'),
                            (Destino == 'Fort Lauderdale')~('Norte América'),
                            (Destino == 'Frankfurt')~('Europa'),
                            (Destino == 'Houston')~('Norte América'),
                            (Destino == 'Liege (Bélgica)')~('Europa'),
                            (Destino == 'Lima')~('Comunidad Andina'),
                            (Destino == 'Maastricht ')~('Europa'),
                            (Destino == 'Madrid')~('Europa'),
                            (Destino == 'Medellin')~('Comunidad Andina'),
                            (Destino == 'Miami')~('Norte América'),
                            (Destino == 'New York')~('Norte América'),
                            (Destino == 'Ostende (Bélgica)')~('Europa'),
                            (Destino == 'Santiago')~('Cono Sur'),
                            (Destino == 'Santo Domingo (Rep.  Dominicana)')~('Centro América'),
                            (Destino == 'Toronto')~('Norte América'),
                            (Destino == 'Viracopos')~('Cono Sur'),
                            (Destino == 'Viru Viru')~('Comunidad Andina'),
                            (Destino == 'Bogotá')~('Comunidad Andina'),
                            (Destino == 'Los Ángeles')~('Norte América'),
                            (Destino == 'México')~('Norte América'),
                            (Destino == 'Panamá')~('Centro América'),
                            (Destino == 'San José')~('Centro América')))

##### Tabulado 26: T.A.I. regular: entrada y salida de pasajeros segun aeropuertos de Quito y Guayaquil,  por ciudades de origen y destino #####
"ENTRADA REGULAR PASAJEROS"
aereo2 <- aereo %>% 
  filter(as.numeric(TipoVuelo) == 1 &  
           as.numeric(Segmento) == 1 &  
           as.numeric(Tráfico) == 1 &   
           as.numeric(Movimiento) == 1)
ar26.1 <- estra.3(aereo2,vertical = "Origen", horizontal = "Destino", relleno = "TOTAL")

"SALIDA REGULAR PASAJEROS"
aereo3 <- aereo %>% 
  filter(as.numeric(TipoVuelo) == 1 &  
           as.numeric(Segmento) == 1 &  
           as.numeric(Tráfico) == 1 &   
           as.numeric(Movimiento) == 2)
ar26.2 <- estra.3(aereo3,vertical = "Destino", horizontal = "Origen", relleno = "TOTAL")

"UNION ENTRADA Y SALIDA REGULAR"
ar26.1 <- ar26.1 %>% 
  select(Origen, Total, Quito, Guayaquil, everything())

ar26.2 <- ar26.2 %>% 
  select(Destino, Total, Quito, Guayaquil, everything())

ar26 <- full_join(ar26.1, ar26.2, join_by(Origen == Destino),
                  suffix = c("", " ")) %>% 
  arrange(Origen)  %>% 
  mutate(TOTAL = sum(Total,`Total `,na.rm = T)) %>% 
  mutate_if(is.numeric, ~replace(.,is.na(.),0)) 

ar26 <- final(ar26,nrow(ar26)) %>% 
  rename(`Total Entrados` = Total,
         `Total Salidos` = `Total `,
         `Total` = TOTAL)

rm(ar26.1, ar26.2)

##### Tabulado 27: T.A.I. regular: entrada y salida de pasajeros,  por ciudades de origen y destino #####
"ENTRADA DE PASAJEROS REGULAR"
ar27.1 <- aereo2 %>% 
  group_by(Origen,Región) %>%
  summarise(entradas = sum(TOTAL, na.rm = T)) %>% 
  group_by(Región) %>%
  mutate(porcentaje  = round_half_up(`entradas` / sum(`entradas`)*100,2)) %>% 
  group_by(Región) %>%
  group_modify(~ add_row(.x,.before=0)) %>% 
  mutate(entradas = ifelse((is.na(entradas)),sum(entradas,na.rm = T),entradas)) %>% 
  mutate(porcentaje = ifelse((is.na(porcentaje)),100,porcentaje)) %>% 
  mutate(Origen = ifelse((is.na(Origen)),str_c("Total Región",Región, sep = " "),Origen))

"SALIDA DE PASAJEROS REGULAR"
ar27.2 <- aereo3 %>% 
  group_by(Destino,Región) %>%
  summarise(salidas = sum(TOTAL, na.rm = T)) %>% 
  group_by(Región) %>%
  mutate(porcentaje  = round_half_up(`salidas` / sum(`salidas`)*100,2)) %>% 
  group_by(Región) %>%
  group_modify(~ add_row(.x,.before=0)) %>% 
  mutate(salidas = ifelse((is.na(salidas)),sum(salidas,na.rm = T),salidas)) %>% 
  mutate(porcentaje = ifelse((is.na(porcentaje)),100,porcentaje)) %>% 
  mutate(Destino = ifelse((is.na(Destino)),str_c("Total Región",Región, sep = " "),Destino))

"UNION ENTRADA Y SALIDA REGULAR"
ar27 <- full_join(ar27.1, ar27.2, join_by(Origen == Destino),
                 suffix = c(".E", ".S")) %>% 
  arrange(Origen) %>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>% 
  mutate(Región.E = ifelse(is.na(Región.E),Región.S,Región.E)) %>% 
  mutate(Región.S = ifelse(is.na(Región.E),Región.S,Región.S)) %>% 
  mutate(n = case_when((Región.E == "Comunidad Andina")~(1),
                       (Región.E == "Centro América")~(2),
                       (Región.E == "Norte América")~(3),
                       (Región.E == "Cono Sur")~(4),
                       (Región.E == "Europa")~(5))) %>% 
  mutate(n2 = ifelse(substr(Origen,1,5) == "Total",1,2)) %>% 
  arrange(n,n2) %>% 
  select(-Región.S, -Región.E,-n,-n2) %>%
  mutate(porcentaje.E = ifelse(porcentaje.E > 100,entradas,porcentaje.E)) %>% 
  mutate(porcentaje.S = ifelse(porcentaje.S > 100,salidas,porcentaje.S)) 

ar27.3 <- ar27 %>% 
  filter(grepl('Total Región', Origen)) %>%
  bind_rows(summarise(., across(where(is.numeric), sum, na.rm=TRUE))) %>% 
  slice(nrow(.))

ar27 <- bind_rows(ar27, ar27.3)
ar27 <- final(ar27, nrow(ar27))

rm(ar27.1, ar27.2, ar27.3)

##### Tabulado 28: T.A.I. no regular: entrada y salida de pasajeros segun aeropuertos de Quito, Guayaquil, Manta y Santa Rosa,  por ciudades de origen y destino #####
"ENTRADA NO REGULAR PASAJEROS"
aereo2 <- aereo %>% 
  filter(as.numeric(TipoVuelo) == 2 &  
           as.numeric(Segmento) == 1 &  
           as.numeric(Tráfico) == 1 &   
           as.numeric(Movimiento) == 1)
ar28.1 <- estra.3(aereo2,vertical = "Origen", horizontal = "Destino", relleno = "TOTAL")

"SALIDA NO REGULAR PASAJEROS"
aereo2 <- aereo %>% 
  filter(as.numeric(TipoVuelo) == 2 &  
           as.numeric(Segmento) == 1 &  
           as.numeric(Tráfico) == 1 &   
           as.numeric(Movimiento) == 2)
ar28.2 <- estra.3(aereo2,vertical = "Destino", horizontal = "Origen", relleno = "TOTAL")

"UNION ENTRADA Y SALIDA NO REGULAR"
ar28.1 <- ar28.1 %>% 
  select(Origen, Total, Quito, Guayaquil, everything())

ar28.2 <- ar28.2 %>% 
  select(Destino, Total, Quito, Guayaquil, everything())

ar28 <- full_join(ar28.1, ar28.2, join_by(Origen == Destino),
                  suffix = c("", " ")) %>% 
  arrange(Origen)  %>% 
  mutate(TOTAL = sum(Total,`Total `,na.rm = T)) %>% 
  mutate_if(is.numeric, ~replace(.,is.na(.),0)) 

ar28 <- final(ar28,nrow(ar28)) %>% 
  rename(`Total Entrados` = Total,
         `Total Salidos` = `Total `,
         `Total` = TOTAL)

rm(ar28.1, ar28.2)

##### Tabulado 29: T.A.I. regular: entrada y salida de carga segun aeropuertos de Quito y Guayaquil,  por ciudades de origen y destino ##### #####
"ENTRADA REGULAR CARGA"
aereo2 <- aereo %>% 
  filter(as.numeric(TipoVuelo) == 1 &  
           as.numeric(Segmento) == 2 &  
           as.numeric(Tráfico) == 1 &   
           as.numeric(Movimiento) == 1)
ar29.1 <- estra.3(aereo2,vertical = "Origen", horizontal = "Destino", relleno = "TOTAL")

"SALIDA REGULAR CARGA"
aereo2 <- aereo %>% 
  filter(as.numeric(TipoVuelo) == 1 &  
           as.numeric(Segmento) == 2 &  
           as.numeric(Tráfico) == 1 &   
           as.numeric(Movimiento) == 2)
ar29.2 <- estra.3(aereo2,vertical = "Destino", horizontal = "Origen", relleno = "TOTAL")

"UNION ENTRADA Y SALIDA REGULAR"
ar29.1 <- ar29.1 %>% 
  select(Origen, Total, Quito, Guayaquil, everything())

ar29.2 <- ar29.2 %>% 
  select(Destino, Total, Quito, Guayaquil, everything())

ar29 <- full_join(ar29.1, ar29.2, join_by(Origen == Destino),
                  suffix = c("", " ")) %>% 
  arrange(Origen)  %>% 
  mutate(TOTAL = sum(Total,`Total `,na.rm = T)) %>% 
  mutate_if(is.numeric, ~replace(.,is.na(.),0)) 

ar29 <- final(ar29,nrow(ar29)) %>% 
  rename(`Total Entrados` = Total,
         `Total Salidos` = `Total `,
         `Total` = TOTAL)

rm(ar29.1, ar29.2)

##### Tabulado 30: T.A.I. no regular: entrada y salida de carga segun aeropuertos de Quito y Guayaquil,  por ciudades de origen y destino #####
"ENTRADA NO REGULAR CARGA"
aereo2 <- aereo %>%
  filter(as.numeric(TipoVuelo) == 2 &
           as.numeric(Segmento) == 2 &
           as.numeric(Tráfico) == 1 &
           as.numeric(Movimiento) == 1)
ar30.1 <- estra.3(aereo2,vertical = "Origen", horizontal = "Destino", relleno = "TOTAL")

"SALIDA NO REGULAR CARGA"
aereo2 <- aereo %>%
  filter(as.numeric(TipoVuelo) == 2 &
           as.numeric(Segmento) == 2 &
           as.numeric(Tráfico) == 1 &
           as.numeric(Movimiento) == 2)
ar30.2 <- estra.3(aereo2,vertical = "Destino", horizontal = "Origen", relleno = "TOTAL")

"UNION ENTRADA Y SALIDA NO REGULAR"
ar30.1 <- ar30.1 %>% 
  select(Origen, Total, Quito, Guayaquil, everything())

ar30.2 <- ar30.2 %>% 
  select(Destino, Total, Quito, Guayaquil, everything())

ar30 <- full_join(ar30.1, ar30.2, join_by(Origen == Destino),
                  suffix = c("", " ")) %>% 
  arrange(Origen)  %>% 
  mutate(TOTAL = sum(Total,`Total `,na.rm = T)) %>% 
  mutate_if(is.numeric, ~replace(.,is.na(.),0)) 

ar30 <- final(ar30,nrow(ar30)) %>% 
  rename(`Total Entrados` = Total,
         `Total Salidos` = `Total `,
         `Total` = TOTAL)

rm(ar30.1, ar30.2)

##### Tabulado 31: T.A.I. regular: pasajeros en transito segun aeropuertos de Quito y Guayaquil, por meses #####
"Nota: La informacion se enuentra disponible en los tabulados"  

##### Tabulado 32: T.A.I. no regular: pasajeros en transito segun aeropuertos de Quito y Guayaquil, por mes #####
"Nota: La informacion se enuentra disponible en los tabulados" 

##### Tabulado 33: T.A.I. regular: entrada y salida de pasajeros del aeropuerto Mariscal Sucre,  por rutas con mayor movimiento #####
"ENTRADA REGULAR PASAJEROS QUITO"
aereo2 <- aereo %>%
  filter(as.numeric(TipoVuelo) == 1 &
           as.numeric(Segmento) == 1 &
           as.numeric(Tráfico) == 1 &
           as.numeric(Movimiento) == 1 &
           Destino == "Quito")

ar33.1 <- estra.participacion(aereo2,vertical = "Origen", horizontal = "Destino", relleno = "TOTAL") %>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  mutate_at(c("Destino","Origen"), ~replace_na(., "Quito")) %>%
  mutate(x1 = "-") %>%
  select(Origen, x1, Destino, total,porcentaje)


"SALIDA REGULAR PASAJEROS QUITO"
aereo2 <- aereo %>%
  filter(as.numeric(TipoVuelo) == 1 &
           as.numeric(Segmento) == 1 &
           as.numeric(Tráfico) == 1 &
           as.numeric(Movimiento) == 2 &
           Origen == "Quito")

ar33.2 <- estra.participacion(aereo2,vertical = "Destino", horizontal = "Origen", relleno = "TOTAL") %>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  mutate_at(c("Destino","Origen"), ~replace_na(., "Quito")) %>%
  mutate(x1 = "-") %>%
  select(Destino, x1, Origen, total,porcentaje)

##### Tabulado 34: T.A.I. regular: entrada y salida de pasajeros del aeropuerto Jose Joaquin de Olmedo,  por rutas con mayor movimiento #####
"ENTRADA REGULAR PASAJEROS GUAYAQUIL"
aereo2 <- aereo %>%
  filter(as.numeric(TipoVuelo) == 1 &
           as.numeric(Segmento) == 1 &
           as.numeric(Tráfico) == 1 &
           as.numeric(Movimiento) == 1 &
           Destino == "Guayaquil")

ar34.1 <- estra.participacion(aereo2,vertical = "Origen", horizontal = "Destino", relleno = "TOTAL") %>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  mutate_at(c("Destino","Origen"), ~replace_na(., "Guayaquil")) %>%
  mutate(x1 = "-") %>%
  select(Origen, x1, Destino, total,porcentaje)


"SALIDA REGULAR PASAJEROS GUAYAQUIL"
aereo2 <- aereo %>%
  filter(as.numeric(TipoVuelo) == 1 &
           as.numeric(Segmento) == 1 &
           as.numeric(Tráfico) == 1 &
           as.numeric(Movimiento) == 2 &
           Origen == "Guayaquil")

ar34.2 <- estra.participacion(aereo2,vertical = "Destino", horizontal = "Origen", relleno = "TOTAL")%>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  mutate_at(c("Destino","Origen"), ~replace_na(., "Quito")) %>%
  mutate(x1 = "-") %>%
  select(Destino, x1, Origen, total,porcentaje)


##### Tabulado 35: T.A.I. no regular: entrada y salida de pasajeros del aeropuerto Mariscal Sucre,  por rutas con mayor movimiento #####
"ENTRADA NO REGULAR PASAJEROS QUITO"
aereo2 <- aereo %>%
  filter(as.numeric(TipoVuelo) == 2 &
           as.numeric(Segmento) == 1 &
           as.numeric(Tráfico) == 1 &
           as.numeric(Movimiento) == 1 &
           Destino == "Quito")

ar35.1 <- estra.participacion(aereo2,vertical = "Origen", horizontal = "Destino", relleno = "TOTAL") %>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  mutate_at(c("Destino","Origen"), ~replace_na(., "Quito")) %>%
  mutate(x1 = "-") %>%
  select(Origen, x1, Destino, total,porcentaje)

"SALIDA NO REGULAR PASAJEROS QUITO"
aereo2 <- aereo %>%
  filter(as.numeric(TipoVuelo) == 2 &
           as.numeric(Segmento) == 1 &
           as.numeric(Tráfico) == 1 &
           as.numeric(Movimiento) == 2 &
           Origen == "Quito")

 ar35.2 <- estra.participacion(aereo2,vertical = "Destino", horizontal = "Origen", relleno = "TOTAL") %>% 
   mutate_if(is.numeric, ~replace_na(., 0)) %>%
   mutate_at(c("Destino","Origen"), ~replace_na(., "Quito")) %>%
   mutate(x1 = "-") %>%
   select(Destino, x1, Origen, total,porcentaje)

##### Tabulado 36: T.A.I. no regular: entrada y salida de pasajeros del aeropuerto Jose Joaquin de Olmedo,  por rutas con mayor movimiento #####
"ENTRADA NO REGULAR PASAJEROS GUAYAQUIL"
aereo2 <- aereo %>%
  filter(as.numeric(TipoVuelo) == 2 &
           as.numeric(Segmento) == 1 &
           as.numeric(Tráfico) == 1 &
           as.numeric(Movimiento) == 1 &
           Destino == "Guayaquil")
ar36.1 <- estra.participacion(aereo2,vertical = "Origen", horizontal = "Destino", relleno = "TOTAL") %>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  mutate_at(c("Destino","Origen"), ~replace_na(., "Quito")) %>%
  mutate(x1 = "-") %>%
  select(Origen, x1, Destino, total,porcentaje)


"SALIDA NO REGULAR PASAJEROS GUAYAQUIL"
aereo2 <- aereo %>%
  filter(as.numeric(TipoVuelo) == 2 &
           as.numeric(Segmento) == 1 &
           as.numeric(Tráfico) == 1 &
           as.numeric(Movimiento) == 2 &
           Origen == "Guayaquil")
ar36.2 <- estra.participacion(aereo2,vertical = "Destino", horizontal = "Origen", relleno = "TOTAL") %>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  mutate_at(c("Destino","Origen"), ~replace_na(., "Quito")) %>%
  mutate(x1 = "-") %>%
  select(Destino, x1, Origen, total,porcentaje)

##### Tabulado 37: T.A.I. no regular: entrada y salida de pasajeros del aeropuerto Eloy Alfaro,  por rutas con mayor movimiento #####
"ENTRADA NO REGULAR PASAJEROS MANTA"
aereo2 <- aereo %>%
  filter(as.numeric(TipoVuelo) == 2 &
           as.numeric(Segmento) == 1 &
           as.numeric(Tráfico) == 1 &
           as.numeric(Movimiento) == 1 &
           Destino == "Manta")
ar37.1 <- estra.participacion(aereo2,vertical = "Origen", horizontal = "Destino", relleno = "TOTAL") %>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  mutate_at(c("Destino","Origen"), ~replace_na(., "Quito")) %>%
  mutate(x1 = "-") %>%
  select(Origen, x1, Destino, total,porcentaje)

"SALIDA NO REGULAR PASAJEROS MANTA"
aereo2 <- aereo %>%
  filter(as.numeric(TipoVuelo) == 2 &
           as.numeric(Segmento) == 1 &
           as.numeric(Tráfico) == 1 &
           as.numeric(Movimiento) == 2 &
           Origen == "Manta")
ar37.2 <- estra.participacion(aereo2,vertical = "Destino", horizontal = "Origen", relleno = "TOTAL") %>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  mutate_at(c("Destino","Origen"), ~replace_na(., "Quito")) %>%
  mutate(x1 = "-") %>%
  select(Destino, x1, Origen, total,porcentaje)

##### Tabulado 38: T.A.I. no regular: entrada y salida de pasajeros del aeropuerto Santa Rosa,  por rutas con mayor movimiento #####
"ENTRADA NO REGULAR PASAJEROS SANTA ROSA"
aereo2 <- aereo %>%
  filter(as.numeric(TipoVuelo) == 2 &
           as.numeric(Segmento) == 1 &
           as.numeric(Tráfico) == 1 &
           as.numeric(Movimiento) == 1 &
           Destino == "Santa Rosa")
ar38.1 <- estra.participacion(aereo2,vertical = "Origen", horizontal = "Destino", relleno = "TOTAL") %>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  mutate_at(c("Destino","Origen"), ~replace_na(., "Quito")) %>%
  mutate(x1 = "-") %>%
  select(Origen, x1, Destino, total,porcentaje)

"SENTRADA NO REGULAR PASAJEROS SANTA ROSA"
aereo2 <- aereo %>%
  filter(as.numeric(TipoVuelo) == 2 &
           as.numeric(Segmento) == 1 &
           as.numeric(Tráfico) == 1 &
           as.numeric(Movimiento) == 2 &
           Origen == "Santa Rosa")
ar38.2 <- estra.participacion(aereo2,vertical = "Destino", horizontal = "Origen", relleno = "TOTAL") %>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  mutate_at(c("Destino","Origen"), ~replace_na(., "Quito")) %>%
  mutate(x1 = "-") %>%
  select(Destino, x1, Origen, total,porcentaje)

##### Tabulado 39: T.A.I. regular: entrada y salida de carga del aeropuerto Mariscal Sucre,  por rutas con mayor movimiento #####
"ENTRADA REGULAR CARGA QUITO"
aereo2 <- aereo %>%
  filter(as.numeric(TipoVuelo) == 1 &
           as.numeric(Segmento) == 2 &
           as.numeric(Tráfico) == 1 &
           as.numeric(Movimiento) == 1 &
           Destino == "Quito")
ar39.1 <- estra.participacion(aereo2,vertical = "Origen", horizontal = "Destino", relleno = "TOTAL") %>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  mutate_at(c("Destino","Origen"), ~replace_na(., "Quito")) %>%
  mutate(x1 = "-") %>%
  select(Origen, x1, Destino, total,porcentaje)

"SALIDA REGULAR CARGA QUITO"
aereo2 <- aereo %>%
  filter(as.numeric(TipoVuelo) == 1 &
           as.numeric(Segmento) == 2 &
           as.numeric(Tráfico) == 1 &
           as.numeric(Movimiento) == 2 &
           Origen == "Quito")
ar39.2 <- estra.participacion(aereo2,vertical = "Destino", horizontal = "Origen", relleno = "TOTAL") %>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  mutate_at(c("Destino","Origen"), ~replace_na(., "Quito")) %>%
  mutate(x1 = "-") %>%
  select(Destino, x1, Origen, total,porcentaje)

##### Tabulado 40: T.A.I. regular: entrada y salida de carga del aeropuerto Jose Joaquin de Olmedo,  por rutas con mayor movimiento #####
"ENTRADA REGULAR CARGA GUAYAQUIL"
aereo2 <- aereo %>%
  filter(as.numeric(TipoVuelo) == 1 &
           as.numeric(Segmento) == 2 &
           as.numeric(Tráfico) == 1 &
           as.numeric(Movimiento) == 1 &
           Destino == "Guayaquil")
ar40.1 <- estra.participacion(aereo2,vertical = "Origen", horizontal = "Destino", relleno = "TOTAL") %>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  mutate_at(c("Destino","Origen"), ~replace_na(., "Quito")) %>%
  mutate(x1 = "-") %>%
  select(Origen, x1, Destino, total,porcentaje)

"SALIDA REGULAR CARGA GUAYAQUIL"
aereo2 <- aereo %>%
  filter(as.numeric(TipoVuelo) == 1 &
           as.numeric(Segmento) == 2 &
           as.numeric(Tráfico) == 1 &
           as.numeric(Movimiento) == 2 &
           Origen == "Guayaquil")
ar40.2 <- estra.participacion(aereo2,vertical = "Destino", horizontal = "Origen", relleno = "TOTAL")%>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  mutate_at(c("Destino","Origen"), ~replace_na(., "Quito")) %>%
  mutate(x1 = "-") %>%
  select(Destino, x1, Origen, total,porcentaje)

##### Tabulado 41: T.A.D. regular: pasajeros transportados,  por rutas #####
aereo2 <- aereo %>% 
  filter(as.numeric(TipoVuelo) == 1 &
           as.numeric(Segmento) == 1 &
           as.numeric(Tráfico) == 2)

ar41 <- aereo.2(aereo2,vertical = "Origen", horizontal = "Destino", relleno = "TOTAL") %>% 
  select(Origen, TOTAL, sort(names(.))) %>% 
  mutate_if(is.numeric, ~replace_na(., 0))

##### Tabulado 42: T.A.D. no regular: pasajeros transportados,  por rutas #####
aereo2 <- aereo %>% 
  filter(as.numeric(TipoVuelo) == 2 &
           as.numeric(Segmento) == 1 &
           as.numeric(Tráfico) == 2)

ar42 <- aereo.2(aereo2,vertical = "Origen", horizontal = "Destino", relleno = "TOTAL") %>% 
  select(Origen, TOTAL, sort(names(.))) %>% 
  mutate_if(is.numeric, ~replace_na(., 0))

##### Tabulado 43: T.A.D. regular: carga transportada,  por rutas #####
aereo2 <- aereo %>% 
  filter(as.numeric(TipoVuelo) == 1 &
           as.numeric(Segmento) == 2 &
           as.numeric(Tráfico) == 2)

ar43 <- aereo.2(aereo2,vertical = "Origen", horizontal = "Destino", relleno = "TOTAL") %>% 
  select(Origen, TOTAL, sort(names(.))) %>% 
  mutate_if(is.numeric, ~replace_na(., 0))

##### Tabulado 44: T.A.D. no regular: carga transportados,  por rutas #####
aereo2 <- aereo %>% 
  filter(as.numeric(TipoVuelo) == 2 &
           as.numeric(Segmento) == 2 &
           as.numeric(Tráfico) == 2)

ar44 <- aereo.2(aereo2,vertical = "Origen", horizontal = "Destino", relleno = "TOTAL") %>% 
  select(Origen, TOTAL, sort(names(.))) %>% 
  mutate_if(is.numeric, ~replace_na(., 0))

##### Tabulado 45: Transporte aereo: Participacion carga entrada y salida segun fuente de informacion,  por mes #####
"Nota: La informacion se enuentra disponible en los tabulados" 

##### Tabulado 46: Transporte aereo: entrada y salida de pasajeros y carga entrada y salida, serie historica 2013-2022 por año #####
"Nota: La serie historica se encuentra en los tabulados"

# ============================================================================ #
######     CREACION DE TABULADOS PARA TRANSPORTE MARITIMO Y FLUVIAL       ######
# ============================================================================ #
"En esta sección se generarán los tabulados concernientes a transporte maritimo 
y fluvial intternacional (T.M.F.I)"

##### Informacion Puerto de Aguas Profundas de Posorja #####
"Nota: Se inserta la informacion de Puerto de Aguas Profundas de Posorja, ya que 
los datos proporcionados no se encuentra en formato para base de datos"

posorja <- data.frame(matrix(0, nrow = 229, ncol = ncol(maritimo)))
names(posorja) <- names(maritimo)
posorja <- posorja %>% 
  mutate(PUERTO = as.character("APG"),
         ETC = 1516170.606 /229,
         STC = 1508652.247 / 229, 
         TC = ETC + STC,
         SAL_TOT_CGEN = 51.86/229,
         BANDERA_C="Otros",
         AGENCIA_NAVIERA_C="Otras Agencias",
         TRAFICO_C="INTERNACIONAL",
         TCONT=91081/229,
         STCC=1508600.38656/229,
         ENT_NCONT_20=7073/229,
         ENT_NCONT_40=17256/229,
         SAL_NCONT_20=8524/229,
         SAL_NCONT_40=58229/229,
         TCONT_20=15597/229,
         TCONT_40=75485/229,
         MES_ENTRADA = c(1,1,1,1,1,1,1,1,1,1,1,1,1,1,
                         2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,
                         3,3,3,3,3,3,3,3,3,3,3,3,3,
                         4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,
                         5,5,5,5,5,5,5,5,5,5,5,5,5,5,
                         6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,
                         7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
                         8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,
                         9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,
                         10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,
                         11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,
                         12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12),
            across(where(is.numeric), ~ ifelse(is.na(.), 0, .))) 

maritimo2 <- rbind(maritimo, posorja)

##### Tabulado 47: T.M.F.I.: Naves arribadas segun puerto,  por banderas #####
mf47.1 <- estra(maritimo2, vertical = "BANDERA_C", horizontal = "PUERTO") %>% 
  arrange(BANDERA_C == "Otros", desc(Total))
mf47 <- final(mf47.1,nrow(mf47.1))
rm(mf47.1)

##### Tabulado 48: T.M.F.I.: Tonelaje de registro neto de las naves entradas y salidas segun meses,  por puerto #####
mf48.1 <- estra.maritimo(maritimo,vertical = "PUERTO",horizontal = "MES_ENTRADA", 
                         relleno = "TRN") %>% 
  mutate_at(c(1), ~replace_na(.,"Total Entradas"))
mf48.2 <- estra.maritimo(maritimo,vertical = "PUERTO",horizontal = "MES_SALIDA", 
                         relleno = "TRN") %>% 
  mutate_at(c(1), ~replace_na(.,"Total Salidas"))
mf48 <- bind_rows(mf48.1, mf48.2)
rm(mf48.1, mf48.2)

##### Tabulado 49: T.M.F.I.: Tonelaje de registro bruto de las naves entradas y salidas segun meses,  por puerto #####
mf49.1 <- estra.maritimo(maritimo,vertical = "PUERTO",horizontal = "MES_ENTRADA", 
                        relleno = "TRB") %>% 
  mutate_at(c(1), ~replace_na(.,"Total Entradas"))
mf49.2 <- estra.maritimo(maritimo,vertical = "PUERTO",horizontal = "MES_SALIDA", 
                        relleno = "TRB") %>% 
  mutate_at(c(1), ~replace_na(.,"Total Salidas"))
mf49 <- bind_rows(mf49.1,mf49.2)
rm(mf49.1, mf49.2)

##### Tabulado 50: T.M.F.I.: Naves arribadas segun meses,  por banderas #####
mf50.1 <- estra(maritimo2,vertical = "BANDERA_C", horizontal = "MES_ENTRADA") %>% 
        arrange(BANDERA_C == "Otros", desc(Total))
mf50 <- final(mf50.1,nrow(mf50.1))
rm(mf50.1)

##### Tabulado 51: T.M.F.I.: Pasajeros entrados y salidos segun meses,  por puerto #####
mf51.1 <- estra.maritimo(maritimo,vertical = "PUERTO",horizontal = "MES_ENTRADA", 
                        relleno = "PASAJ_ENT") %>% 
  mutate(PUERTO = as.character(PUERTO)) %>% 
  mutate_at(c("PUERTO"), ~replace(.,is.na(.),"Total Entradas"))
mf51.2 <- estra.maritimo(maritimo, vertical = "PUERTO",horizontal = "MES_SALIDA", 
                        relleno = "PASAJ_SAL") %>% 
  mutate(PUERTO = as.character(PUERTO)) %>% 
  mutate_at(c("PUERTO"), ~replace(.,is.na(.),"Total Salidas"))
mf51 <- bind_rows(mf51.1, mf51.2)
rm(mf51.1, mf51.2)

##### Tabulado 52: T.M.F.I.: Total de carga entrada y salida segun meses,  por puerto #####
"Nota: Se incluye información adicional de Posorja"

mf52.1.1 <- estra.maritimo(maritimo,vertical = "PUERTO",horizontal = "MES_ENTRADA", relleno = "ETC") %>% 
  mutate_at(c(1), ~replace_na(.,"Total Entradas")) %>% 
  select(Enero, Febrero, Marzo, Abril, Mayo, Junio, Julio, Agosto, Septiembre, Octubre, Noviembre, Diciembre) %>% 
  mutate(across(everything(), ~ ifelse(row_number() == 3, . + 1516170.606 / 12, .))) %>% 
  mutate(across(everything(), ~ ifelse(row_number() == 1, . + 1516170.606 / 12, .)))

mf52.1.2 <- estra.maritimo(maritimo,vertical = "PUERTO",horizontal = "MES_ENTRADA", relleno = "ETC") %>% 
  mutate_at(c(1), ~replace_na(.,"Total Entradas")) %>% 
  select(PUERTO, Total) %>% 
  mutate(Total= ifelse(row_number() == 3, Total + 1516170.606, Total)) %>% 
  mutate(Total= ifelse(row_number() == 1, Total + 1516170.606, Total))

mf52.1 <- cbind(mf52.1.2, mf52.1.1)
  
mf52.2.1 <- estra.maritimo(maritimo,vertical = "PUERTO",horizontal = "MES_SALIDA", relleno = "STC") %>% 
  mutate_at(c(1), ~replace_na(.,"Total Salidas")) %>% 
  select(Enero, Febrero, Marzo, Abril, Mayo, Junio, Julio, Agosto, Septiembre, Octubre, Noviembre, Diciembre) %>% 
  mutate(across(everything(), ~ ifelse(row_number() == 3, . + 1508652.247 / 12, .))) %>% 
  mutate(across(everything(), ~ ifelse(row_number() == 1, . + 1508652.247 / 12, .)))

mf52.2.2 <- estra.maritimo(maritimo,vertical = "PUERTO",horizontal = "MES_SALIDA", relleno = "STC") %>% 
  mutate_at(c(1), ~replace_na(.,"Total Salidas")) %>% 
  select(PUERTO, Total) %>% 
  mutate(Total= ifelse(row_number() == 3, Total + 1508652.247, Total)) %>% 
  mutate(Total= ifelse(row_number() == 1, Total + 1508652.247, Total))

mf52.2 <- cbind(mf52.2.2, mf52.2.1)

mf52 <- bind_rows(mf52.1, mf52.2)
rm(mf52.1, mf52.1.1, mf52.1.2, mf52.2, mf52.2.1, mf52.2.2)

##### Tabulado 53: T.M.F.I.: Naves arribadas, tonelaje de registro neto, tonelaje de registro bruto, carga entrada y salida,  por banderas #####
maritimo3 <- maritimo2 %>% 
  mutate(T = 1)

mf53.1 <- estra.frecuencias(maritimo3,vertical = "BANDERA_C",horizontal1 = "T",horizontal2 = "TRN",
                         horizontal3 = "TRB",horizontal4 = "ETC",horizontal5 = "STC") %>% 
  arrange(BANDERA_C == "Otros", desc(a)) %>% 
  rename(`Número de naves arribadas` = a,
         `Tonelaje de registro neto` = b,
         `Tonelaje de registro bruto` = c,
         `Entrada total de carga` = d,
         `Salida total de carga` = e)
mf53 <- final(mf53.1,nrow(mf53.1))
rm(mf53.1)

##### Tabulado 54: T.M.F.I.: Autoridad Portuaria de Esmeraldas (APE): Naves arribadas, tonelaje de registro neto, tonelaje de registro bruto, carga entrada y salida,  por banderas #####
maritimo4 <- maritimo3 %>%
  filter(TRAFICO_C == 'INTERNACIONAL' & PUERTO == 'APE')

mf54 <- estra.frecuencias(maritimo4,vertical = "BANDERA_C",horizontal1 = "T",horizontal2 = "TRN",
                         horizontal3 = "TRB",horizontal4 = "ETC",horizontal5 = "STC") %>% 
  rename(`Número de naves arribadas` = a,
         `Tonelaje de registro neto` = b,
         `Tonelaje de registro bruto` = c,
         `Entrada total de carga` = d,
         `Salida total de carga` = e)

##### Tabulado 55: T.M.F.I.: Autoridad Portuaria de Manta (APM): Naves arribadas, tonelaje de registro neto, tonelaje de registro bruto, carga entrada y salida,  por banderas #####
maritimo4 <- maritimo3 %>%
  filter(TRAFICO_C == 'INTERNACIONAL' & PUERTO == 'APM')

mf55 <- estra.frecuencias(maritimo4,vertical = "BANDERA_C",horizontal1 = "T",horizontal2 = "TRN",
                          horizontal3 = "TRB",horizontal4 = "ETC",horizontal5 = "STC") %>% 
  rename(`Número de naves arribadas` = a,
         `Tonelaje de registro neto` = b,
         `Tonelaje de registro bruto` = c,
         `Entrada total de carga` = d,
         `Salida total de carga` = e)

##### Tabulado 56: T.M.F.I.: Autoridad Portuaria de Guayaquil (APG): Naves arribadas, tonelaje de registro neto, tonelaje de registro bruto, carga entrada y salida,  por banderas #####
maritimo4 <- maritimo3 %>%
  filter(TRAFICO_C == 'INTERNACIONAL' & PUERTO == 'APG')

mf56.1 <- estra.frecuencias(maritimo4,vertical = "BANDERA_C",horizontal1 = "T",horizontal2 = "TRN",
                          horizontal3 = "TRB",horizontal4 = "ETC",horizontal5 = "STC") %>% 
    arrange(BANDERA_C == "Otros", desc(a)) %>% 
    rename(`Número de naves arribadas` = a,
         `Tonelaje de registro neto` = b,
         `Tonelaje de registro bruto` = c,
         `Entrada total de carga` = d,
         `Salida total de carga` = e)
mf56 <- final(mf56.1,nrow(mf56.1))
rm(mf56.1)

##### Tabulado 57: T.M.F.I.: Autoridad Portuaria de Puerto Bolivar (APPB): Naves arribadas, tonelaje de registro neto, tonelaje de registro bruto, carga entrada y salida,  por banderas #####
maritimo4 <- maritimo3 %>%
  filter(TRAFICO_C == 'INTERNACIONAL' & PUERTO == 'APPB')

mf57 <- estra.frecuencias(maritimo4,vertical = "BANDERA_C",horizontal1 = "T",horizontal2 = "TRN",
                          horizontal3 = "TRB",horizontal4 = "ETC",horizontal5 = "STC") %>% 
  rename(`Número de naves arribadas` = a,
         `Tonelaje de registro neto` = b,
         `Tonelaje de registro bruto` = c,
         `Entrada total de carga` = d,
         `Salida total de carga` = e)

##### Tabulado 58: T.M.F.I.: Superintendencia Petrolera de Balaro (SUINBA): Naves arribadas, tonelaje de registro neto, tonelaje de registro bruto, carga entrada y salida,  por banderas #####
maritimo4 <- maritimo3 %>%
  filter(TRAFICO_C == 'INTERNACIONAL' & PUERTO == 'SUINBA')

mf58 <- estra.frecuencias(maritimo4,vertical = "BANDERA_C",horizontal1 = "T",horizontal2 = "TRN",
                          horizontal3 = "TRB",horizontal4 = "ETC",horizontal5 = "STC") %>% 
  rename(`Número de naves arribadas` = a,
         `Tonelaje de registro neto` = b,
         `Tonelaje de registro bruto` = c,
         `Entrada total de carga` = d,
         `Salida total de carga` = e)

##### Tabulado 59: T.M.F.I.: Superintendencia Petrolera de la Libertad (SUINLI): Naves arribadas, tonelaje de registro neto, tonelaje de registro bruto, carga entrada y salida,  por banderas #####
maritimo4 <- maritimo3 %>%
  filter(TRAFICO_C == 'INTERNACIONAL' & PUERTO == 'SUINLI')

mf59 <- estra.frecuencias(maritimo4,vertical = "BANDERA_C",horizontal1 = "T",horizontal2 = "TRN",
                          horizontal3 = "TRB",horizontal4 = "ETC",horizontal5 = "STC") %>% 
  rename(`Número de naves arribadas` = a,
         `Tonelaje de registro neto` = b,
         `Tonelaje de registro bruto` = c,
         `Entrada total de carga` = d,
         `Salida total de carga` = e)

##### Tabulado 60: T.M.F.I.: Superintendencia Petrolera el Salitral (SUINSA): Naves arribadas, tonelaje de registro neto, tonelaje de registro bruto, carga entrada y salida,  por banderas #####
maritimo4 <- maritimo3 %>%
  filter(TRAFICO_C == 'INTERNACIONAL' & PUERTO == 'SUINSA')

mf60 <- estra.frecuencias(maritimo4,vertical = "BANDERA_C",horizontal1 = "T",horizontal2 = "TRN",
                          horizontal3 = "TRB",horizontal4 = "ETC",horizontal5 = "STC") %>% 
  rename(`Número de naves arribadas` = a,
         `Tonelaje de registro neto` = b,
         `Tonelaje de registro bruto` = c,
         `Entrada total de carga` = d,
         `Salida total de carga` = e)

##### Tabulado 61: T.M.F.I.: Terminales Portuarios Habilitados (TPH): Naves arribadas, tonelaje de registro neto, tonelaje de registro bruto, carga entrada y salida,  por banderas #####
maritimo4 <- maritimo3 %>%
  filter(TRAFICO_C == 'INTERNACIONAL' & PUERTO == 'TPH')

mf61 <- estra.frecuencias(maritimo4,vertical = "BANDERA_C",horizontal1 = "T",horizontal2 = "TRN",
                          horizontal3 = "TRB",horizontal4 = "ETC",horizontal5 = "STC") %>% 
  rename(`Número de naves arribadas` = a,
         `Tonelaje de registro neto` = b,
         `Tonelaje de registro bruto` = c,
         `Entrada total de carga` = d,
         `Salida total de carga` = e)

##### Tabulado 62: T.M.F.I.: Contenedores con carga movilizada,  por agencias navieras #####
mf62.1 <- maritimo3 %>% 
  select(AGENCIA_NAVIERA_C, TCONT, ENT_NCONT_20, ENT_NCONT_40, SAL_NCONT_20, SAL_NCONT_40, TCONT_20, TCONT_40) %>% 
  group_by(AGENCIA_NAVIERA_C) %>%
  summarise(TCONT = sum(TCONT, na.rm = TRUE),
            ENT_NCONT_20 = sum(ENT_NCONT_20, na.rm = TRUE),
            ENT_NCONT_40 = sum(ENT_NCONT_40, na.rm = TRUE),
            SAL_NCONT_20 = sum(SAL_NCONT_20, na.rm = TRUE),
            SAL_NCONT_40 = sum(SAL_NCONT_40, na.rm = TRUE),
            TCONT_20 = sum(TCONT_20, na.rm = TRUE),
            TCONT_40 = sum(TCONT_40, na.rm = TRUE)) %>% 
  ungroup() %>%
  bind_rows(summarise(., across(where(is.numeric), sum, na.rm=TRUE))) %>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  rename_at(-c(1:2), ~ str_to_title(.)) %>% 
  mutate_at(c(1:1), ~ str_to_title(.))
  
mf62.1 <- mf62.1 %>% 
  mutate(AGENCIA_NAVIERA_C=ifelse(rank(-TCONT, ties.method = "first") <= 20, AGENCIA_NAVIERA_C, 
                      "Otras Agencias")) %>% 
  group_by(AGENCIA_NAVIERA_C) %>% 
  summarise(across(everything(), sum)) %>% 
  ungroup() %>% 
  arrange(AGENCIA_NAVIERA_C == "Otras Agencias", desc(TCONT))

mf62 <- final(mf62.1,nrow(mf62.1)) 
rm(mf62.1)

##### Tabulado 63: T.M.F.I.: Movimientos de tipos de carga de exportacion,  por agencias navieras #####
maritimo4 <- maritimo3 %>%
  filter(STC != 0)

mf63.1 <- estra.frecuencias(maritimo4,vertical = "AGENCIA_NAVIERA_C",horizontal1 = "STC",horizontal2 = "SAL_TOT_CGEN",
                         horizontal3 = "STCC",horizontal4 = "SAL_TOT_CSOL",horizontal5 = "SAL_TOT_CLIQ") %>% 
  arrange(AGENCIA_NAVIERA_C == "Otras Agencias", desc(a)) %>% 
  rename(`Salida total de carga` = a,
         `Salida de carga general` = b,
         `Salida de carga contenerizada` = c,
         `Salida de carga sólida` = d,
         `Salida de carga líquida` = e)
mf63 <- final(mf63.1,nrow(mf63.1))
rm(mf63.1)

##### Tabulado 64: T.M.F.: Participacion de exportaciones e importaciones segun fuente de iformacion,  por meses #####
"Nota: La informacion se enuentra disponible en los tabulados" 

##### Tabulado 65: T.M.F.I.: Naves arribadas, carga entrada y salida segun puerto, serie historica 2013-2022 por año #####
"Nota: La serie historica se encuentra en los tabulados"

# ============================================================================ #
#####               DISEÑO Y EXPORTACIÓN DE TABULADOS A EXCEL              ##### 
# ============================================================================ #
"En esta sección se diseñara y exportara los tabulados en formato excel"

##### Configuracion tabulados #####
wb <- loadWorkbook("2022_TABULADOS_DISEÑO.xlsx")

#tabulado 1
writeData(wb,
          "1",
          vm1, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "1", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE) 

#Tabulado 2
writeData(wb,
          "2",
          vm2, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "2", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE) 

#Tabulado 3
writeData(wb,
          "3",
          vm3, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "3", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE) 

#Tabulado 4
writeData(wb,
          "4",
          vm4, 
          startRow = 7, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

#Tabulado 5
writeData(wb,
          "5",
          vm5, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "5", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE) 

#Tabulado 6
writeData(wb,
          "6",
          vm6, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "6", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE) 

#Tabulado 7
writeData(wb,
          "7",
          vm7, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "7", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 8
writeData(wb,
          "8",
          vm8, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "8", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 9
writeData(wb,
          "9",
          vm9, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "9", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 10
writeData(wb,
          "10",
          vm10, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "10", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 11
writeData(wb,
          "11",
          vm11, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "11", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 12
writeData(wb,
          "12",
          vm12, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "12", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 13
writeData(wb,
          "13",
          vm13, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "13", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 14
writeData(wb,
          "14",
          vm14, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

#Tabulado 15
writeData(wb,
          "15",
          vm15, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

#Tabulado 16
writeData(wb,
          "16",
          vm16, 
          startRow = 3, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "16", 
          "Total", 
          startCol = 1, 
          startRow = 3, 
          rowNames = FALSE)

#Tabulado 17
"Nota: La serie historica se encuentra en los tabulados"

#Tabulado 18
writeData(wb,
          "18",
          st18, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "18", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 19
writeData(wb,
          "19",
          st19, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "19", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 20
writeData(wb,
          "20",
          st20, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "20", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 21
writeData(wb,
          "21",
          st21, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "21", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 22
writeData(wb,
          "22",
          st22, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "22", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 23
writeData(wb,
          "23",
          st23, 
          startRow = 3, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "23", 
          "Total", 
          startCol = 1, 
          startRow = 3, 
          rowNames = FALSE)

#Tabulado 24
writeData(wb,
          "24",
          st24, 
          startRow = 3, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "24", 
          "Total", 
          startCol = 1, 
          startRow = 3, 
          rowNames = FALSE)

#Tabulado 25
"Nota: La serie historica se encuentra en los tabulados"

#Tabulado 26
writeData(wb,
          "26",
          ar26, 
          startRow = 5, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "26", 
          "Total", 
          startCol = 1, 
          startRow = 5, 
          rowNames = FALSE)

#Tabulado 27
writeData(wb,
          "27",
          ar27, 
          startRow = 5, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "27", 
          "Total", 
          startCol = 1, 
          startRow = 5, 
          rowNames = FALSE)

tabrestx <- createStyle(fontName = "Century Gothic", 
                        fontSize = 12,
                        fontColour = "#404040", 
                        numFmt = "0.0,0\\%", 
                        halign = "right",
                        valign = "center",
                        border = "TopBottomLeftRight",
                        borderColour = "#a6a6a6",
                        wrapText = TRUE)

addStyle(wb, 
         "27", 
         tabrestx, 
         cols = c(3,5), 
         rows = 7:(nrow(ar27)+4), 
         gridExpand = TRUE)

tabrestxx <- createStyle(fontName = "Century Gothic", 
                         fontSize = 12,
                         fontColour = "#404040", 
                         numFmt = "0.0,0\\%", 
                         halign = "right",
                         valign = "center",
                         border = "TopBottomLeftRight",
                         borderColour = "#a6a6a6",
                         wrapText = TRUE, 
                         textDecoration = "bold")

addStyle(wb, 
         "27", 
         tabrestxx, 
         cols = c(3,5), 
         rows = which(ar27$Origen == "Total Región Comunidad Andina")+4, 
         gridExpand = TRUE)

addStyle(wb, 
         "27", 
         tabrestxx, 
         cols = c(3,5), 
         rows = which(ar27$Origen == "Total Región Centro América")+4, 
         gridExpand = TRUE)

addStyle(wb, 
         "27", 
         tabrestxx, 
         cols = c(3,5), 
         rows = which(ar27$Origen == "Total Región Norte América")+4, 
         gridExpand = TRUE)

addStyle(wb, 
         "27", 
         tabrestxx, 
         cols = c(3,5), 
         rows = which(ar27$Origen == "Total Región Cono Sur")+4, 
         gridExpand = TRUE)

addStyle(wb, 
         "27", 
         tabrestxx, 
         cols = c(3,5), 
         rows = which(ar27$Origen == "Total Región Europa")+4, 
         gridExpand = TRUE)

#Tabulado 28
writeData(wb,
          "28",
          ar28, 
          startRow = 5, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "28", 
          "Total", 
          startCol = 1, 
          startRow = 5, 
          rowNames = FALSE)

#Tabulado 29
writeData(wb,
          "29",
          ar29, 
          startRow = 5, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "29", 
          "Total", 
          startCol = 1, 
          startRow = 5, 
          rowNames = FALSE)

#Tabulado 30
writeData(wb,
          "30",
          ar30, 
          startRow = 5, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "30", 
          "Total", 
          startCol = 1, 
          startRow = 5, 
          rowNames = FALSE)

#Tabulado 31
"Nota: La informacion se enuentra disponible en los tabulados" 

#Tabulado 32
"Nota: La informacion se enuentra disponible en los tabulados" 

#Tabulado 33
writeData(wb,
          "33",
          ar33.1, 
          startRow = 5, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "33", 
          "Total", 
          startCol = 1, 
          startRow = 5, 
          rowNames = FALSE)

writeData(wb,
          "33",
          ar33.2, 
          startRow = 5, 
          startCol = 6,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "33", 
          "Total", 
          startCol = 6, 
          startRow = 5, 
          rowNames = FALSE)

addStyle(wb, 
         "33", 
         tabrestx, 
         cols = 5, 
         rows = 6:(nrow(ar33.1)+4), 
         gridExpand = TRUE)


addStyle(wb, 
         "33", 
         tabrestx, 
         cols = 10, 
         rows = 6:(nrow(ar33.2)+4), 
         gridExpand = TRUE)

addStyle(wb, 
         "33", 
         tabrestxx, 
         cols = c(5,10), 
         rows = 5, 
         gridExpand = TRUE)

#Tabulado 34
writeData(wb,
          "34",
          ar34.1, 
          startRow = 5, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "34", 
          "Total", 
          startCol = 1, 
          startRow = 5, 
          rowNames = FALSE)

writeData(wb,
          "34",
          ar34.2, 
          startRow = 5, 
          startCol = 6,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "34", 
          "Total", 
          startCol = 6, 
          startRow = 5, 
          rowNames = FALSE)

addStyle(wb, 
         "34", 
         tabrestx, 
         cols = 5, 
         rows = 6:(nrow(ar34.1)+4), 
         gridExpand = TRUE)


addStyle(wb, 
         "34", 
         tabrestx, 
         cols = 10, 
         rows = 6:(nrow(ar34.2)+4), 
         gridExpand = TRUE)

addStyle(wb, 
         "34", 
         tabrestxx, 
         cols = c(5,10), 
         rows = 5, 
         gridExpand = TRUE)

#Tabulado 35
writeData(wb,
          "35",
          ar35.1, 
          startRow = 5, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "35", 
          "Total", 
          startCol = 1, 
          startRow = 5, 
          rowNames = FALSE)

writeData(wb,
          "35",
          ar35.2, 
          startRow = 5, 
          startCol = 6,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "35", 
          "Total", 
          startCol = 6, 
          startRow = 5, 
          rowNames = FALSE)

addStyle(wb, 
         "35", 
         tabrestx, 
         cols = 5, 
         rows = 6:(nrow(ar35.1)+4), 
         gridExpand = TRUE)


addStyle(wb, 
         "35", 
         tabrestx, 
         cols = 10, 
         rows = 6:(nrow(ar35.2)+4), 
         gridExpand = TRUE)

addStyle(wb, 
         "35", 
         tabrestxx, 
         cols = c(5,10), 
         rows = 5, 
         gridExpand = TRUE)

#Tabulado 36
writeData(wb,
          "36",
          ar36.1, 
          startRow = 5, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "36", 
          "Total", 
          startCol = 1, 
          startRow = 5, 
          rowNames = FALSE)

writeData(wb,
          "36",
          ar36.2, 
          startRow = 5, 
          startCol = 6,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "36", 
          "Total", 
          startCol = 6, 
          startRow = 5, 
          rowNames = FALSE)

addStyle(wb, 
         "36", 
         tabrestx, 
         cols = 5, 
         rows = 6:(nrow(ar36.1)+4), 
         gridExpand = TRUE)


addStyle(wb, 
         "36", 
         tabrestx, 
         cols = 10, 
         rows = 6:(nrow(ar36.2)+4), 
         gridExpand = TRUE)

addStyle(wb, 
         "36", 
         tabrestxx, 
         cols = c(5,10), 
         rows = 5, 
         gridExpand = TRUE)

#Tabulado 37
writeData(wb,
          "37",
          ar37.1, 
          startRow = 5, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "37", 
          "Total", 
          startCol = 1, 
          startRow = 5, 
          rowNames = FALSE)

writeData(wb,
          "37",
          ar37.2, 
          startRow = 5, 
          startCol = 6,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "37", 
          "Total", 
          startCol = 6, 
          startRow = 5, 
          rowNames = FALSE)

addStyle(wb, 
         "37", 
         tabrestx, 
         cols = 5, 
         rows = 6:(nrow(ar37.1)+4), 
         gridExpand = TRUE)

addStyle(wb, 
         "37", 
         tabrestx, 
         cols = 10, 
         rows = 6:(nrow(ar37.2)+4), 
         gridExpand = TRUE)

addStyle(wb, 
         "37", 
         tabrestxx, 
         cols = c(5,10), 
         rows = 5, 
         gridExpand = TRUE)

#Tabulado 38
writeData(wb,
          "38",
          ar38.1, 
          startRow = 5, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "38", 
          "Total", 
          startCol = 1, 
          startRow = 5, 
          rowNames = FALSE)

writeData(wb,
          "38",
          ar38.2, 
          startRow = 5, 
          startCol = 6,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "38", 
          "Total", 
          startCol = 6, 
          startRow = 5, 
          rowNames = FALSE)

addStyle(wb, 
         "38", 
         tabrestx, 
         cols = 5, 
         rows = 6:(nrow(ar38.1)+4), 
         gridExpand = TRUE)


addStyle(wb, 
         "38", 
         tabrestx, 
         cols = 10, 
         rows = 6:(nrow(ar38.2)+4), 
         gridExpand = TRUE)

addStyle(wb, 
         "38", 
         tabrestxx, 
         cols = c(5,10), 
         rows = 5, 
         gridExpand = TRUE)
          
#Tabulado 39
writeData(wb,
          "39",
          ar39.1, 
          startRow = 5, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "39", 
          "Total", 
          startCol = 1, 
          startRow = 5, 
          rowNames = FALSE)

writeData(wb,
          "39",
          ar39.2, 
          startRow = 5, 
          startCol = 6,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "39", 
          "Total", 
          startCol = 6, 
          startRow = 5, 
          rowNames = FALSE)

addStyle(wb, 
         "39", 
         tabrestx, 
         cols = 5, 
         rows = 6:(nrow(ar39.1)+4), 
         gridExpand = TRUE)


addStyle(wb, 
         "39", 
         tabrestx, 
         cols = 10, 
         rows = 6:(nrow(ar39.2)+4), 
         gridExpand = TRUE)

addStyle(wb, 
         "39", 
         tabrestxx, 
         cols = c(5,10), 
         rows = 5, 
         gridExpand = TRUE)

#Tabulado 40
writeData(wb,
          "40",
          ar40.1, 
          startRow = 5, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "40", 
          "Total", 
          startCol = 1, 
          startRow = 5, 
          rowNames = FALSE)

writeData(wb,
          "40",
          ar40.2, 
          startRow = 5, 
          startCol = 6,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "40", 
          "Total", 
          startCol = 6, 
          startRow = 5, 
          rowNames = FALSE)

addStyle(wb, 
         "40", 
         tabrestx, 
         cols = 5, 
         rows = 6:(nrow(ar40.1)+4), 
         gridExpand = TRUE)


addStyle(wb, 
         "40", 
         tabrestx, 
         cols = 10, 
         rows = 6:(nrow(ar40.2)+4), 
         gridExpand = TRUE)

addStyle(wb, 
         "40", 
         tabrestxx, 
         cols = c(5,10), 
         rows = 5, 
         gridExpand = TRUE)

#Tabulado 41
writeData(wb,
          "41",
          ar41, 
          startRow = 4, 
          startCol = 2,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "41", 
          "Total", 
          startCol = 2, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 42
writeData(wb,
          "42",
          ar42, 
          startRow = 4, 
          startCol = 2,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "42", 
          "Total", 
          startCol = 2, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 43
writeData(wb,
          "43",
          ar43, 
          startRow = 4, 
          startCol = 2,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "43", 
          "Total", 
          startCol = 2, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 44
writeData(wb,
          "44",
          ar44, 
          startRow = 4, 
          startCol = 2,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "44", 
          "Total", 
          startCol = 2, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 45
"Nota: La informacion se enuentra disponible en los tabulados" 

#Tabulado 46
"Nota: La serie historica se encuentra en los tabulados"

#Tabulado 47
writeData(wb,
          "47",
          mf47, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "47", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 48
writeData(wb,
          "48",
          mf48, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "48", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 49
writeData(wb,
          "49",
          mf49, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "49", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 50
writeData(wb,
          "50",
          mf50, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "50", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 51
writeData(wb,
          "51",
          mf51, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "51", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 52
writeData(wb,
          "52",
          mf52, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "52", 
          "Total", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 53
writeData(wb,
          "53",
          mf53, 
          startRow = 3, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "53", 
          "Total", 
          startCol = 1, 
          startRow = 3, 
          rowNames = FALSE)

#Tabulado 54
writeData(wb,
          "54",
          mf54, 
          startRow = 3, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "54", 
          "Total", 
          startCol = 1, 
          startRow = 3, 
          rowNames = FALSE)

#Tabulado 55
writeData(wb,
          "55",
          mf55, 
          startRow = 3, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "55", 
          "Total", 
          startCol = 1, 
          startRow = 3, 
          rowNames = FALSE)

#Tabulado 56
writeData(wb,
          "56",
          mf56, 
          startRow = 3, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "56", 
          "Total", 
          startCol = 1, 
          startRow = 3, 
          rowNames = FALSE)

#Tabulado 57
writeData(wb,
          "57",
          mf57, 
          startRow = 3, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "57", 
          "Total", 
          startCol = 1, 
          startRow = 3, 
          rowNames = FALSE)

#Tabulado 58
writeData(wb,
          "58",
          mf58, 
          startRow = 3, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "58", 
          "Total", 
          startCol = 1, 
          startRow = 3, 
          rowNames = FALSE)

#Tabulado 59
writeData(wb,
          "59",
          mf59, 
          startRow = 3, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "59", 
          "Total", 
          startCol = 1, 
          startRow = 3, 
          rowNames = FALSE)

#Tabulado 60
writeData(wb,
          "60",
          mf60, 
          startRow = 3, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "60", 
          "Total", 
          startCol = 1, 
          startRow = 3, 
          rowNames = FALSE)

#Tabulado 61
writeData(wb,
          "61",
          mf61, 
          startRow = 3, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "61", 
          "Total", 
          startCol = 1, 
          startRow = 3, 
          rowNames = FALSE)

#Tabulado 62
writeData(wb,
          "62",
          mf62, 
          startRow = 3, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "62", 
          "Total", 
          startCol = 1, 
          startRow = 3, 
          rowNames = FALSE)

#Tabulado 63
writeData(wb,
          "63",
          mf63, 
          startRow = 3, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "63", 
          "Total", 
          startCol = 1, 
          startRow = 3, 
          rowNames = FALSE)

#Tabulado 64
"Nota: La informacion se enuentra disponible en los tabulados" 

#Tabulado 65
"Nota: La serie historica se encuentra en los tabulados"

#####################   Exportación de tabulados a Excel   #####################

saveWorkbook(wb, "2022_TABULADOS.xlsx",overwrite = TRUE)

#####                           FIN DEL SCRIPT                             #####

